//line parser.y:2
package main

import __yyfmt__ "fmt"

//line parser.y:2
import (
	"bytes"
	"fmt"
	"io"
	"os"
)

type node struct {
	name       string
	children   []node
	attributes map[string]string
}

func (n node) String() string {
	buf := new(bytes.Buffer)
	n.print(buf, " ")
	return buf.String()
}

func (n node) print(out io.Writer, indent string) {
	if len(n.attributes) > 0 {
		fmt.Fprintf(out, "\n%v%v %s", indent, n.name, n.attributes)
	} else {
		fmt.Fprintf(out, "\n%v%v", indent, n.name)
	}
	for _, nn := range n.children {
		nn.print(out, indent+"  ")
	}
}

func Node(name string) node {
	return node{name: name, attributes: make(map[string]string)}
}

func (n node) append(nn ...node) node {
	n.children = append(n.children, nn...)
	return n
}

func (n node) attribute(key string, value string) node {
	n.attributes[key] = value
	return n
}

//line parser.y:50
type yySymType struct {
	yys   int
	node  node
	token string
	value string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"'('",
	"')'",
	"';'",
	"'{'",
	"'}'",
	"']'",
	"'\"'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser.y:1220
const src = `<?php
isset($a, $b);
`

func main() {
	yyDebug = 0
	yyErrorVerbose = true
	l := newLexer(bytes.NewBufferString(src), os.Stdout, "file.name")
	yyParse(l)
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 43,
	69, 421,
	133, 421,
	153, 421,
	162, 421,
	-2, 430,
	-1, 47,
	159, 424,
	-2, 453,
	-1, 79,
	69, 423,
	133, 423,
	153, 423,
	159, 426,
	162, 423,
	-2, 386,
	-1, 102,
	153, 417,
	-2, 413,
	-1, 215,
	69, 421,
	133, 421,
	153, 421,
	162, 421,
	-2, 318,
	-1, 218,
	159, 426,
	-2, 423,
	-1, 219,
	69, 421,
	133, 421,
	153, 421,
	162, 421,
	-2, 320,
	-1, 337,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 342,
	-1, 338,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 343,
	-1, 339,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 344,
	-1, 340,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 345,
	-1, 341,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 346,
	-1, 342,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 347,
	-1, 343,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 348,
	-1, 344,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 349,
	-1, 345,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 350,
	-1, 352,
	9, 219,
	160, 219,
	-2, 421,
	-1, 392,
	69, 422,
	133, 422,
	153, 422,
	159, 425,
	162, 422,
	-2, 352,
	-1, 395,
	159, 444,
	-2, 414,
	-1, 397,
	159, 446,
	-2, 462,
	-1, 475,
	159, 444,
	-2, 415,
	-1, 477,
	159, 446,
	-2, 463,
	-1, 512,
	9, 202,
	160, 202,
	164, 202,
	-2, 421,
	-1, 547,
	160, 282,
	-2, 287,
	-1, 565,
	159, 425,
	-2, 422,
	-1, 623,
	15, 190,
	160, 190,
	-2, 421,
	-1, 649,
	88, 261,
	-2, 267,
	-1, 677,
	9, 201,
	160, 201,
	164, 201,
	-2, 421,
	-1, 698,
	15, 191,
	160, 191,
	-2, 421,
	-1, 748,
	15, 193,
	160, 193,
	-2, 428,
	-1, 813,
	105, 76,
	-2, 78,
	-1, 831,
	160, 282,
	-2, 287,
}

const yyPrivate = 57344

const yyLast = 6958

var yyAct = [...]int{

	27, 126, 764, 752, 631, 102, 554, 651, 401, 805,
	763, 743, 780, 635, 713, 552, 122, 542, 183, 622,
	633, 133, 133, 133, 306, 107, 145, 691, 605, 505,
	636, 680, 268, 604, 180, 74, 111, 117, 487, 79,
	360, 351, 75, 302, 301, 299, 8, 7, 5, 549,
	300, 214, 270, 6, 220, 221, 222, 223, 224, 139,
	387, 225, 226, 227, 228, 229, 230, 231, 232, 144,
	233, 234, 235, 138, 141, 298, 121, 2, 4, 124,
	256, 123, 132, 396, 248, 249, 244, 251, 252, 479,
	239, 218, 218, 128, 216, 216, 478, 748, 672, 100,
	659, 77, 667, 567, 135, 136, 272, 561, 509, 275,
	861, 862, 618, 279, 280, 388, 245, 100, 815, 776,
	773, 589, 771, 731, 590, 738, 739, 853, 304, 800,
	793, 308, 309, 760, 276, 292, 278, 263, 751, 738,
	739, 285, 725, 100, 291, 710, 211, 514, 320, 321,
	322, 323, 324, 325, 326, 327, 328, 329, 330, 331,
	332, 333, 334, 335, 336, 337, 338, 339, 340, 341,
	342, 343, 344, 345, 113, 347, 349, 101, 353, 244,
	783, 355, 241, 642, 655, 656, 657, 654, 653, 652,
	281, 389, 264, 266, 737, 101, 370, 372, 373, 374,
	375, 376, 377, 378, 379, 380, 381, 382, 383, 245,
	213, 384, 133, 386, 134, 588, 218, 262, 391, 216,
	134, 101, 781, 682, 113, 43, 100, 553, 648, 514,
	113, 650, 100, 362, 179, 514, 856, 133, 854, 212,
	395, 475, 294, 617, 481, 110, 288, 488, 489, 390,
	112, 490, 767, 768, 514, 841, 835, 834, 624, 498,
	354, 821, 789, 502, 346, 784, 506, 366, 272, 831,
	777, 814, 243, 397, 477, 241, 319, 215, 219, 735,
	723, 799, 257, 695, 694, 759, 692, 495, 316, 690,
	626, 687, 129, 533, 385, 108, 529, 134, 129, 218,
	508, 108, 216, 292, 101, 608, 518, 113, 483, 100,
	101, 602, 521, 218, 524, 106, 216, 515, 538, 394,
	145, 368, 476, 314, 357, 8, 7, 5, 484, 842,
	525, 312, 6, 311, 492, 697, 494, 482, 310, 282,
	485, 494, 492, 294, 288, 258, 259, 788, 787, 541,
	139, 750, 782, 778, 699, 625, 104, 4, 516, 501,
	772, 705, 679, 675, 670, 522, 556, 551, 557, 620,
	555, 558, 559, 609, 528, 129, 595, 277, 108, 678,
	217, 265, 547, 149, 151, 150, 637, 101, 536, 539,
	564, 537, 756, 545, 566, 532, 110, 530, 519, 513,
	548, 569, 352, 174, 367, 175, 147, 148, 152, 154,
	153, 166, 167, 164, 165, 168, 169, 170, 171, 172,
	162, 163, 156, 157, 155, 158, 160, 161, 318, 173,
	149, 151, 150, 365, 655, 656, 657, 654, 653, 652,
	315, 159, 113, 655, 656, 657, 654, 653, 652, 267,
	174, 781, 175, 147, 148, 152, 154, 153, 166, 167,
	164, 165, 168, 169, 170, 171, 172, 162, 163, 156,
	157, 155, 158, 160, 161, 313, 173, 563, 648, 113,
	696, 650, 133, 573, 113, 500, 568, 648, 159, 250,
	650, 639, 640, 290, 113, 293, 287, 113, 247, 512,
	246, 210, 178, 177, 577, 176, 131, 130, 594, 127,
	129, 272, 597, 108, 272, 838, 571, 275, 109, 390,
	575, 796, 592, 290, 119, 120, 576, 480, 639, 640,
	758, 238, 237, 613, 308, 615, 290, 726, 113, 290,
	292, 619, 606, 290, 574, 275, 600, 129, 496, 524,
	108, 524, 129, 638, 550, 108, 555, 643, 614, 361,
	8, 7, 5, 596, 572, 523, 570, 6, 118, 658,
	364, 836, 703, 704, 116, 603, 257, 716, 715, 488,
	837, 782, 255, 218, 218, 621, 216, 216, 527, 257,
	674, 520, 4, 305, 506, 289, 673, 714, 641, 795,
	655, 656, 657, 654, 653, 652, 142, 611, 257, 286,
	825, 257, 497, 495, 688, 113, 253, 671, 586, 681,
	125, 628, 683, 676, 685, 606, 669, 272, 524, 526,
	257, 701, 514, 524, 524, 261, 663, 359, 218, 258,
	259, 216, 686, 638, 648, 358, 693, 650, 785, 738,
	739, 491, 258, 259, 555, 717, 113, 718, 711, 700,
	741, 738, 739, 824, 218, 720, 724, 216, 709, 189,
	493, 258, 259, 254, 258, 259, 188, 72, 73, 272,
	584, 187, 260, 119, 120, 181, 236, 719, 190, 191,
	284, 308, 159, 258, 259, 192, 194, 193, 728, 681,
	272, 606, 184, 708, 733, 158, 160, 161, 524, 173,
	524, 727, 638, 732, 730, 736, 582, 746, 585, 583,
	740, 159, 742, 45, 769, 753, 757, 754, 185, 722,
	173, 828, 747, 369, 182, 765, 721, 218, 801, 779,
	216, 770, 159, 761, 317, 295, 774, 786, 775, 659,
	729, 607, 684, 792, 706, 524, 791, 593, 578, 638,
	543, 186, 798, 115, 534, 510, 1, 794, 802, 352,
	623, 811, 744, 486, 810, 797, 655, 656, 657, 654,
	653, 652, 820, 655, 656, 657, 654, 653, 652, 59,
	242, 58, 819, 240, 76, 827, 103, 504, 363, 823,
	114, 283, 830, 48, 49, 78, 581, 811, 68, 860,
	810, 829, 808, 809, 833, 807, 806, 804, 766, 647,
	839, 840, 762, 712, 677, 649, 646, 648, 645, 845,
	650, 843, 702, 790, 630, 627, 846, 638, 271, 269,
	350, 851, 555, 847, 143, 850, 849, 140, 137, 616,
	698, 816, 307, 855, 817, 857, 610, 15, 858, 42,
	14, 41, 47, 744, 863, 44, 632, 393, 634, 37,
	644, 83, 84, 85, 86, 87, 296, 3, 399, 755,
	69, 70, 174, 71, 175, 147, 148, 152, 154, 153,
	166, 167, 164, 165, 168, 169, 170, 171, 172, 162,
	163, 156, 157, 155, 158, 160, 161, 707, 173, 0,
	0, 0, 0, 0, 0, 0, 53, 54, 0, 0,
	159, 0, 55, 623, 56, 51, 52, 60, 61, 62,
	63, 64, 65, 66, 67, 0, 105, 80, 50, 0,
	0, 0, 0, 24, 72, 73, 0, 0, 0, 0,
	46, 88, 89, 35, 0, 100, 0, 26, 0, 0,
	0, 106, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 12, 22, 32, 0, 0, 33, 11, 0, 23,
	0, 28, 81, 82, 9, 38, 39, 40, 0, 0,
	0, 0, 104, 0, 97, 93, 94, 95, 90, 91,
	0, 0, 0, 0, 0, 0, 98, 0, 0, 0,
	0, 10, 96, 92, 108, 0, 57, 150, 31, 13,
	601, 0, 99, 101, 83, 84, 85, 86, 87, 0,
	0, 0, 0, 69, 70, 174, 71, 175, 147, 148,
	152, 154, 153, 166, 167, 164, 165, 168, 169, 170,
	171, 172, 162, 163, 156, 157, 155, 158, 160, 161,
	0, 173, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 159, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 67, 0, 105,
	80, 50, 0, 0, 0, 0, 24, 72, 73, 0,
	0, 0, 0, 46, 88, 89, 35, 0, 100, 0,
	26, 0, 0, 0, 106, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 12, 22, 32, 0, 0, 33,
	11, 0, 23, 0, 28, 81, 82, 9, 38, 39,
	40, 0, 0, 0, 0, 104, 0, 97, 93, 94,
	95, 90, 91, 0, 0, 0, 0, 0, 0, 98,
	0, 0, 0, 0, 10, 96, 92, 108, 0, 57,
	0, 31, 13, 517, 0, 99, 101, 408, 409, 410,
	411, 412, 0, 413, 414, 415, 451, 452, 174, 0,
	175, 147, 148, 152, 154, 153, 166, 167, 164, 165,
	168, 169, 170, 171, 172, 162, 163, 156, 157, 155,
	158, 160, 161, 0, 173, 162, 163, 156, 157, 155,
	158, 160, 161, 0, 173, 0, 159, 0, 0, 416,
	0, 0, 0, 0, 0, 0, 159, 0, 0, 0,
	0, 0, 0, 417, 418, 0, 421, 422, 423, 402,
	403, 404, 405, 406, 407, 419, 420, 0, 0, 398,
	0, 100, 0, 0, 0, 0, 0, 0, 424, 425,
	426, 427, 428, 429, 430, 431, 432, 433, 434, 454,
	455, 456, 457, 458, 446, 447, 448, 449, 450, 435,
	436, 437, 438, 439, 440, 441, 442, 443, 444, 445,
	0, 466, 464, 465, 461, 462, 0, 453, 459, 460,
	467, 468, 470, 469, 471, 472, 0, 0, 0, 0,
	0, 83, 84, 85, 86, 87, 0, 463, 474, 473,
	69, 70, 0, 71, 0, 400, 0, 0, 0, 101,
	152, 154, 153, 166, 167, 164, 165, 168, 169, 170,
	171, 172, 162, 163, 156, 157, 155, 158, 160, 161,
	0, 173, 0, 0, 0, 0, 53, 54, 0, 0,
	0, 0, 55, 159, 56, 51, 52, 60, 61, 62,
	63, 64, 65, 66, 67, 0, 105, 80, 50, 0,
	0, 0, 0, 24, 72, 73, 0, 0, 0, 0,
	46, 88, 89, 35, 0, 100, 0, 26, 0, 0,
	0, 106, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 12, 22, 32, 0, 0, 33, 11, 0, 23,
	0, 28, 81, 82, 9, 38, 39, 40, 0, 0,
	0, 0, 104, 0, 97, 93, 94, 95, 90, 91,
	0, 0, 0, 0, 0, 0, 98, 0, 0, 0,
	0, 10, 96, 92, 108, 0, 57, 0, 31, 13,
	0, 0, 99, 101, 83, 84, 85, 86, 87, 0,
	0, 0, 0, 69, 70, 0, 71, 175, 147, 148,
	152, 154, 153, 166, 167, 164, 165, 168, 169, 170,
	171, 172, 162, 163, 156, 157, 155, 158, 160, 161,
	0, 173, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 159, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 67, 0, 105,
	80, 50, 0, 0, 0, 0, 24, 72, 73, 0,
	0, 0, 0, 46, 88, 89, 35, 0, 100, 0,
	26, 0, 0, 0, 106, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 81, 82, 303, 38, 39,
	40, 0, 0, 0, 0, 104, 0, 97, 93, 94,
	95, 90, 91, 0, 0, 0, 0, 0, 0, 98,
	0, 0, 0, 0, 129, 96, 92, 108, 0, 57,
	0, 31, 13, 864, 0, 99, 101, 83, 84, 85,
	86, 87, 0, 0, 0, 0, 69, 70, 0, 71,
	148, 152, 154, 153, 166, 167, 164, 165, 168, 169,
	170, 171, 172, 162, 163, 156, 157, 155, 158, 160,
	161, 0, 173, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 53, 54, 159, 0, 0, 0, 55, 0,
	56, 51, 52, 60, 61, 62, 63, 64, 65, 66,
	67, 0, 105, 80, 50, 0, 0, 0, 0, 24,
	72, 73, 0, 0, 0, 0, 46, 88, 89, 35,
	0, 100, 0, 26, 0, 0, 0, 106, 25, 17,
	16, 0, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 36, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 81, 82,
	303, 38, 39, 40, 0, 0, 0, 0, 104, 0,
	97, 93, 94, 95, 90, 91, 0, 0, 0, 0,
	0, 0, 98, 0, 0, 0, 0, 129, 96, 92,
	108, 0, 57, 0, 31, 13, 859, 0, 99, 101,
	83, 84, 85, 86, 87, 0, 0, 0, 0, 69,
	70, 0, 71, 0, 0, 154, 153, 166, 167, 164,
	165, 168, 169, 170, 171, 172, 162, 163, 156, 157,
	155, 158, 160, 161, 0, 173, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 53, 54, 159, 0, 0,
	0, 55, 0, 56, 51, 52, 60, 61, 62, 63,
	64, 65, 66, 67, 0, 105, 80, 50, 0, 0,
	0, 0, 24, 72, 73, 0, 0, 0, 0, 46,
	88, 89, 35, 0, 100, 0, 26, 0, 0, 0,
	106, 25, 17, 16, 0, 18, 852, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 36,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 81, 82, 303, 38, 39, 40, 0, 0, 0,
	0, 104, 0, 97, 93, 94, 95, 90, 91, 0,
	0, 0, 0, 0, 0, 98, 0, 0, 0, 0,
	129, 96, 92, 108, 0, 57, 0, 31, 13, 0,
	0, 99, 101, 83, 84, 85, 86, 87, 0, 0,
	0, 0, 69, 70, 0, 71, 153, 166, 167, 164,
	165, 168, 169, 170, 171, 172, 162, 163, 156, 157,
	155, 158, 160, 161, 0, 173, 156, 157, 155, 158,
	160, 161, 0, 173, 0, 0, 0, 159, 53, 54,
	0, 0, 0, 0, 55, 159, 56, 51, 52, 60,
	61, 62, 63, 64, 65, 66, 67, 0, 105, 80,
	50, 0, 0, 0, 0, 24, 72, 73, 0, 0,
	0, 0, 46, 88, 89, 35, 0, 100, 0, 26,
	0, 0, 0, 106, 25, 17, 16, 0, 18, 0,
	29, 0, 30, 0, 0, 19, 0, 0, 0, 20,
	21, 34, 36, 0, 22, 32, 0, 0, 33, 0,
	0, 23, 0, 28, 81, 82, 303, 38, 39, 40,
	0, 0, 0, 0, 104, 0, 97, 93, 94, 95,
	90, 91, 0, 0, 0, 0, 0, 0, 98, 0,
	0, 0, 0, 129, 96, 92, 108, 0, 57, 0,
	31, 13, 844, 0, 99, 101, 83, 84, 85, 86,
	87, 0, 0, 0, 0, 69, 70, 0, 71, 166,
	167, 164, 165, 168, 169, 170, 171, 172, 162, 163,
	156, 157, 155, 158, 160, 161, 0, 173, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 159,
	0, 53, 54, 0, 0, 0, 0, 55, 0, 56,
	51, 52, 60, 61, 62, 63, 64, 65, 66, 67,
	0, 105, 80, 50, 0, 0, 0, 0, 24, 72,
	73, 0, 0, 0, 0, 46, 88, 89, 35, 0,
	100, 0, 26, 0, 0, 0, 106, 25, 17, 16,
	0, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 36, 0, 22, 32, 0,
	0, 33, 0, 0, 23, 0, 28, 81, 82, 303,
	38, 39, 40, 0, 0, 0, 0, 104, 0, 97,
	93, 94, 95, 90, 91, 0, 0, 0, 0, 0,
	0, 98, 0, 0, 0, 0, 129, 96, 92, 108,
	0, 57, 0, 31, 13, 826, 0, 99, 101, 83,
	84, 85, 86, 87, 0, 0, 0, 0, 69, 70,
	0, 71, 169, 170, 171, 172, 162, 163, 156, 157,
	155, 158, 160, 161, 0, 173, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 159, 0, 0,
	0, 0, 0, 0, 53, 54, 0, 0, 0, 0,
	55, 0, 56, 51, 52, 60, 61, 62, 63, 64,
	65, 66, 67, 0, 105, 80, 50, 0, 0, 0,
	0, 24, 72, 73, 0, 0, 0, 0, 46, 88,
	89, 35, 0, 100, 0, 26, 0, 0, 0, 106,
	25, 17, 16, 0, 18, 0, 29, 822, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 36, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	81, 82, 303, 38, 39, 40, 0, 0, 0, 0,
	104, 0, 97, 93, 94, 95, 90, 91, 0, 0,
	0, 0, 0, 0, 98, 0, 0, 0, 0, 129,
	96, 92, 108, 0, 57, 0, 31, 13, 0, 0,
	99, 101, 83, 84, 85, 86, 87, 0, 0, 0,
	0, 69, 70, 0, 71, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 195,
	196, 197, 198, 200, 201, 202, 203, 204, 205, 206,
	207, 199, 0, 0, 0, 0, 0, 53, 54, 0,
	0, 0, 0, 55, 0, 56, 51, 52, 60, 61,
	62, 63, 64, 65, 66, 67, 0, 105, 80, 50,
	208, 209, 0, 0, 24, 72, 73, 0, 0, 0,
	0, 46, 88, 89, 35, 0, 100, 0, 26, 0,
	0, 0, 106, 25, 17, 16, 0, 18, 0, 29,
	0, 30, 749, 0, 19, 0, 0, 0, 20, 21,
	34, 36, 0, 22, 32, 0, 0, 33, 0, 0,
	23, 0, 28, 81, 82, 303, 38, 39, 40, 0,
	0, 0, 0, 104, 0, 97, 93, 94, 95, 90,
	91, 0, 0, 0, 0, 0, 0, 98, 0, 0,
	0, 0, 129, 96, 92, 108, 0, 57, 0, 31,
	13, 0, 0, 99, 101, 83, 84, 85, 86, 87,
	0, 0, 0, 0, 69, 70, 0, 71, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	53, 54, 0, 0, 0, 0, 55, 0, 56, 51,
	52, 60, 61, 62, 63, 64, 65, 66, 67, 0,
	105, 80, 50, 0, 0, 0, 0, 24, 72, 73,
	0, 0, 0, 0, 46, 88, 89, 35, 0, 100,
	0, 26, 0, 0, 0, 106, 25, 17, 16, 734,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 36, 0, 22, 32, 0, 0,
	33, 0, 0, 23, 0, 28, 81, 82, 303, 38,
	39, 40, 0, 0, 0, 0, 104, 0, 97, 93,
	94, 95, 90, 91, 0, 0, 0, 0, 0, 0,
	98, 0, 0, 0, 0, 129, 96, 92, 108, 0,
	57, 0, 31, 13, 0, 0, 99, 101, 83, 84,
	85, 86, 87, 0, 0, 0, 0, 69, 70, 0,
	71, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 53, 54, 0, 0, 0, 0, 55,
	0, 56, 51, 52, 60, 61, 62, 63, 64, 65,
	66, 67, 0, 105, 80, 50, 0, 0, 0, 662,
	24, 72, 73, 0, 0, 0, 0, 46, 88, 89,
	35, 0, 100, 0, 26, 0, 0, 0, 106, 25,
	17, 16, 0, 18, 0, 29, 0, 30, 0, 0,
	19, 0, 0, 0, 20, 21, 34, 36, 0, 22,
	32, 0, 0, 33, 0, 0, 23, 0, 28, 81,
	82, 303, 38, 39, 40, 0, 0, 0, 0, 104,
	0, 97, 93, 94, 95, 90, 91, 0, 0, 0,
	0, 0, 0, 98, 0, 0, 0, 0, 129, 96,
	92, 108, 0, 57, 0, 31, 13, 0, 0, 99,
	101, 83, 84, 85, 86, 87, 0, 0, 0, 0,
	69, 70, 0, 71, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 53, 54, 0, 0,
	0, 0, 55, 0, 56, 51, 52, 60, 61, 62,
	63, 64, 65, 66, 67, 0, 105, 80, 50, 0,
	0, 0, 0, 24, 72, 73, 0, 0, 0, 0,
	46, 88, 89, 35, 0, 100, 0, 26, 0, 0,
	0, 106, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 81, 82, 303, 38, 39, 40, 0, 0,
	0, 0, 104, 0, 97, 93, 94, 95, 90, 91,
	0, 0, 0, 0, 0, 0, 98, 0, 0, 0,
	0, 129, 96, 92, 108, 0, 57, 0, 31, 13,
	546, 0, 99, 101, 83, 84, 85, 86, 87, 0,
	0, 0, 0, 69, 70, 0, 71, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 0, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 67, 0, 105,
	80, 50, 0, 0, 0, 0, 24, 72, 73, 0,
	0, 0, 0, 46, 88, 89, 35, 0, 100, 0,
	26, 0, 0, 0, 106, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 36, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 81, 82, 303, 38, 39,
	40, 0, 0, 0, 0, 104, 0, 97, 93, 94,
	95, 90, 91, 0, 0, 0, 0, 0, 0, 98,
	0, 0, 0, 0, 129, 96, 92, 108, 0, 57,
	0, 31, 13, 297, 0, 99, 101, 83, 84, 85,
	86, 87, 0, 0, 0, 0, 69, 70, 0, 71,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 53, 54, 0, 0, 0, 0, 55, 0,
	56, 51, 52, 60, 61, 62, 63, 64, 65, 66,
	67, 0, 105, 80, 50, 0, 0, 0, 0, 24,
	72, 73, 0, 0, 0, 0, 46, 88, 89, 35,
	0, 100, 0, 26, 0, 0, 0, 106, 25, 17,
	16, 0, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 36, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 81, 82,
	303, 38, 39, 40, 0, 0, 0, 0, 104, 0,
	97, 93, 94, 95, 90, 91, 0, 0, 0, 0,
	0, 0, 98, 0, 0, 0, 0, 129, 96, 92,
	108, 0, 57, 0, 31, 13, 151, 150, 99, 101,
	408, 409, 410, 411, 412, 0, 413, 414, 415, 451,
	452, 0, 0, 0, 0, 174, 0, 175, 147, 148,
	152, 154, 153, 166, 167, 164, 165, 168, 169, 170,
	171, 172, 162, 163, 156, 157, 155, 158, 160, 161,
	0, 173, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 416, 159, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 417, 418, 0, 421,
	422, 423, 402, 403, 404, 405, 406, 407, 419, 420,
	0, 0, 813, 0, 0, 0, 0, 0, 0, 0,
	0, 424, 425, 426, 427, 428, 429, 430, 431, 432,
	433, 434, 454, 455, 456, 457, 458, 446, 447, 448,
	449, 450, 435, 436, 437, 438, 439, 440, 441, 442,
	443, 444, 445, 0, 466, 464, 465, 461, 462, 0,
	453, 459, 460, 467, 468, 470, 469, 471, 472, 408,
	409, 410, 411, 412, 0, 413, 414, 415, 451, 452,
	812, 474, 473, 108, 0, 0, 0, 0, 0, 832,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 416, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 417, 418, 0, 421, 422,
	423, 402, 403, 404, 405, 406, 407, 419, 420, 0,
	0, 813, 0, 0, 0, 0, 0, 0, 0, 0,
	424, 425, 426, 427, 428, 429, 430, 431, 432, 433,
	434, 454, 455, 456, 457, 458, 446, 447, 448, 449,
	450, 435, 436, 437, 438, 439, 440, 441, 442, 443,
	444, 445, 0, 466, 464, 465, 461, 462, 0, 453,
	459, 460, 467, 468, 470, 469, 471, 472, 0, 0,
	0, 0, 0, 0, 83, 84, 85, 86, 87, 812,
	474, 473, 108, 69, 70, 0, 71, 0, 803, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 745, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 53,
	54, 0, 0, 0, 0, 55, 0, 56, 51, 52,
	60, 61, 62, 63, 64, 65, 66, 67, 0, 105,
	80, 50, 0, 0, 0, 0, 24, 0, 0, 0,
	0, 0, 0, 46, 88, 89, 35, 0, 100, 0,
	26, 0, 0, 0, 106, 25, 17, 16, 0, 18,
	0, 29, 0, 30, 0, 0, 19, 0, 0, 0,
	20, 21, 34, 0, 0, 22, 32, 0, 0, 33,
	0, 0, 23, 0, 28, 81, 82, 0, 0, 0,
	0, 0, 0, 0, 0, 104, 0, 97, 93, 94,
	95, 90, 91, 0, 0, 0, 0, 0, 0, 98,
	0, 0, 0, 0, 129, 96, 92, 108, 0, 57,
	0, 31, 13, 0, 0, 99, 101, 83, 84, 85,
	86, 87, 0, 0, 0, 0, 69, 70, 0, 71,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 818, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 53, 54, 0, 0, 0, 0, 55, 0,
	56, 51, 52, 60, 61, 62, 63, 64, 65, 66,
	67, 0, 105, 80, 50, 0, 0, 0, 0, 24,
	0, 0, 0, 0, 0, 0, 46, 88, 89, 35,
	0, 100, 0, 26, 0, 0, 0, 106, 25, 17,
	16, 0, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 0, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 81, 82,
	0, 0, 0, 0, 0, 0, 0, 0, 104, 0,
	97, 93, 94, 95, 90, 91, 0, 0, 0, 0,
	0, 0, 98, 0, 0, 0, 0, 129, 96, 92,
	108, 0, 57, 0, 31, 13, 0, 0, 99, 101,
	83, 84, 85, 86, 87, 0, 0, 0, 0, 69,
	70, 0, 71, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 664, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 53, 54, 0, 0, 0,
	0, 55, 0, 56, 51, 52, 60, 61, 62, 63,
	64, 65, 66, 67, 0, 105, 80, 50, 0, 0,
	0, 0, 24, 0, 0, 0, 0, 0, 0, 46,
	88, 89, 35, 0, 100, 0, 26, 0, 0, 0,
	106, 25, 17, 16, 0, 18, 0, 29, 0, 30,
	0, 0, 19, 0, 0, 0, 20, 21, 34, 0,
	0, 22, 32, 0, 0, 33, 0, 0, 23, 0,
	28, 81, 82, 0, 0, 0, 0, 0, 0, 0,
	0, 104, 0, 97, 93, 94, 95, 90, 91, 0,
	0, 0, 0, 0, 0, 98, 0, 0, 0, 0,
	129, 96, 92, 108, 0, 57, 0, 31, 13, 0,
	0, 99, 101, 83, 84, 85, 86, 87, 0, 0,
	0, 0, 69, 70, 0, 71, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	629, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 53, 54,
	0, 0, 0, 0, 55, 0, 56, 51, 52, 60,
	61, 62, 63, 64, 65, 66, 67, 0, 105, 80,
	50, 0, 0, 0, 0, 24, 0, 0, 0, 0,
	0, 0, 46, 88, 89, 35, 0, 100, 0, 26,
	0, 0, 0, 106, 25, 17, 16, 0, 18, 0,
	29, 0, 30, 0, 0, 19, 0, 0, 0, 20,
	21, 34, 0, 0, 22, 32, 0, 0, 33, 0,
	0, 23, 0, 28, 81, 82, 0, 0, 0, 0,
	0, 0, 0, 0, 104, 0, 97, 93, 94, 95,
	90, 91, 0, 0, 0, 0, 0, 0, 98, 0,
	0, 0, 0, 129, 96, 92, 108, 0, 57, 0,
	31, 13, 0, 0, 99, 101, 83, 84, 85, 86,
	87, 0, 0, 0, 0, 69, 70, 0, 71, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 612, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 53, 54, 0, 0, 0, 0, 55, 0, 56,
	51, 52, 60, 61, 62, 63, 64, 65, 66, 67,
	0, 105, 80, 50, 0, 0, 0, 0, 24, 0,
	0, 0, 0, 0, 0, 46, 88, 89, 35, 0,
	100, 0, 26, 0, 0, 0, 106, 25, 17, 16,
	0, 18, 0, 29, 0, 30, 0, 0, 19, 0,
	0, 0, 20, 21, 34, 0, 0, 22, 32, 0,
	0, 33, 0, 0, 23, 0, 28, 81, 82, 0,
	0, 0, 0, 0, 0, 0, 0, 104, 0, 97,
	93, 94, 95, 90, 91, 0, 0, 0, 0, 0,
	0, 98, 0, 0, 0, 0, 129, 96, 92, 108,
	0, 57, 0, 31, 13, 0, 0, 99, 101, 83,
	84, 85, 86, 87, 0, 0, 0, 0, 69, 70,
	0, 71, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 53, 54, 0, 0, 0, 0,
	55, 0, 56, 51, 52, 60, 61, 62, 63, 64,
	65, 66, 67, 0, 105, 80, 50, 0, 0, 0,
	0, 24, 0, 0, 0, 0, 0, 0, 46, 88,
	89, 35, 0, 100, 0, 26, 0, 0, 0, 106,
	25, 17, 16, 0, 18, 0, 29, 0, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 0, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	81, 82, 105, 0, 0, 0, 0, 0, 0, 134,
	104, 0, 97, 93, 94, 95, 90, 91, 0, 113,
	0, 100, 0, 0, 98, 0, 0, 106, 0, 129,
	96, 92, 108, 0, 57, 0, 31, 13, 0, 0,
	99, 101, 408, 409, 410, 411, 412, 0, 413, 414,
	415, 451, 452, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 104, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 129, 0, 0,
	108, 0, 217, 0, 416, 0, 0, 0, 0, 101,
	0, 0, 0, 0, 0, 0, 0, 0, 417, 418,
	0, 421, 422, 423, 402, 403, 404, 405, 406, 407,
	419, 420, 0, 0, 398, 0, 0, 0, 0, 0,
	0, 0, 0, 424, 425, 426, 427, 428, 429, 430,
	431, 432, 433, 434, 454, 455, 456, 457, 458, 446,
	447, 448, 449, 450, 435, 436, 437, 438, 439, 440,
	441, 442, 443, 444, 445, 0, 466, 464, 465, 461,
	462, 0, 453, 459, 460, 467, 468, 470, 469, 471,
	472, 408, 409, 410, 411, 412, 0, 413, 414, 415,
	451, 452, 463, 474, 473, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 416, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 417, 418, 0,
	421, 422, 423, 655, 656, 657, 654, 653, 652, 419,
	420, 0, 0, 848, 0, 0, 0, 0, 0, 0,
	0, 0, 424, 425, 426, 427, 428, 429, 430, 431,
	432, 433, 434, 454, 455, 456, 457, 458, 446, 447,
	448, 449, 450, 435, 436, 437, 438, 439, 440, 441,
	442, 443, 444, 445, 0, 466, 464, 465, 461, 462,
	0, 453, 459, 460, 467, 468, 470, 469, 471, 472,
	0, 0, 0, 0, 0, 83, 84, 85, 86, 87,
	0, 463, 474, 473, 69, 70, 0, 71, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 273, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	53, 54, 0, 0, 0, 0, 55, 0, 56, 51,
	52, 60, 61, 62, 63, 64, 65, 66, 67, 0,
	105, 80, 50, 0, 0, 0, 0, 134, 0, 0,
	0, 0, 0, 0, 0, 88, 89, 113, 0, 100,
	0, 0, 0, 0, 0, 106, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 83,
	84, 85, 86, 87, 0, 0, 81, 82, 69, 70,
	0, 71, 0, 0, 0, 274, 104, 0, 97, 93,
	94, 95, 90, 91, 0, 0, 0, 0, 0, 0,
	98, 0, 598, 0, 0, 129, 96, 92, 108, 0,
	57, 0, 0, 0, 53, 54, 99, 101, 0, 0,
	55, 0, 56, 51, 52, 60, 61, 62, 63, 64,
	65, 66, 67, 0, 105, 80, 50, 0, 0, 0,
	0, 134, 0, 0, 0, 0, 0, 0, 0, 88,
	89, 113, 0, 100, 0, 0, 0, 0, 0, 106,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 83, 84, 85, 86, 87, 0, 0,
	81, 82, 69, 70, 0, 71, 0, 0, 0, 599,
	104, 0, 97, 93, 94, 95, 90, 91, 0, 0,
	0, 0, 0, 0, 98, 0, 0, 0, 0, 129,
	96, 92, 108, 0, 57, 0, 0, 0, 53, 54,
	99, 101, 0, 0, 55, 0, 56, 51, 52, 60,
	61, 62, 63, 64, 65, 66, 67, 0, 105, 80,
	50, 0, 0, 0, 0, 134, 0, 0, 0, 0,
	0, 0, 0, 88, 89, 113, 0, 100, 0, 0,
	0, 0, 0, 106, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 83, 84, 85,
	86, 87, 0, 0, 81, 82, 69, 70, 0, 71,
	0, 0, 0, 0, 104, 0, 97, 93, 94, 95,
	90, 91, 0, 0, 0, 0, 0, 0, 98, 0,
	0, 0, 0, 129, 96, 92, 108, 507, 57, 503,
	0, 0, 53, 54, 99, 101, 0, 0, 55, 0,
	56, 51, 52, 60, 61, 62, 63, 64, 65, 66,
	67, 0, 105, 80, 50, 0, 0, 0, 0, 134,
	0, 0, 0, 0, 0, 0, 0, 88, 89, 113,
	0, 100, 0, 0, 0, 0, 0, 106, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 83, 84, 85, 86, 87, 0, 0, 81, 82,
	69, 70, 0, 71, 0, 0, 0, 0, 104, 0,
	97, 93, 94, 95, 90, 91, 0, 0, 0, 0,
	0, 0, 98, 0, 0, 0, 0, 129, 96, 92,
	108, 507, 57, 0, 0, 0, 53, 54, 99, 101,
	0, 0, 55, 0, 56, 51, 52, 60, 61, 62,
	63, 64, 65, 66, 67, 0, 105, 80, 50, 0,
	0, 0, 0, 134, 0, 0, 0, 0, 0, 0,
	0, 88, 89, 113, 499, 100, 0, 0, 0, 0,
	0, 106, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 83, 84, 85, 86, 87,
	0, 0, 81, 82, 69, 70, 0, 71, 0, 0,
	0, 0, 104, 0, 97, 93, 94, 95, 90, 91,
	0, 0, 0, 0, 0, 0, 98, 0, 371, 0,
	0, 129, 96, 92, 108, 0, 57, 0, 0, 0,
	53, 54, 99, 101, 0, 0, 55, 0, 56, 51,
	52, 60, 61, 62, 63, 64, 65, 66, 67, 0,
	105, 80, 50, 0, 0, 0, 0, 134, 0, 0,
	0, 0, 0, 0, 0, 88, 89, 113, 0, 100,
	0, 0, 0, 0, 0, 106, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 83,
	84, 85, 86, 87, 0, 0, 81, 82, 69, 70,
	0, 71, 0, 0, 0, 0, 104, 0, 97, 93,
	94, 95, 90, 91, 0, 0, 348, 0, 0, 0,
	98, 0, 0, 0, 0, 129, 96, 92, 108, 0,
	57, 0, 0, 0, 53, 54, 99, 101, 0, 0,
	55, 0, 56, 51, 52, 60, 61, 62, 63, 64,
	65, 66, 67, 0, 105, 80, 50, 0, 0, 0,
	0, 134, 0, 0, 0, 0, 0, 0, 0, 88,
	89, 113, 0, 100, 0, 0, 0, 0, 0, 106,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 83, 84, 85, 86, 87, 0, 0,
	81, 82, 69, 70, 0, 71, 0, 0, 0, 0,
	104, 0, 97, 93, 94, 95, 90, 91, 0, 0,
	0, 0, 0, 0, 98, 0, 0, 0, 0, 129,
	96, 92, 108, 0, 57, 0, 0, 0, 53, 54,
	99, 101, 0, 0, 55, 0, 56, 51, 52, 60,
	61, 62, 63, 64, 65, 66, 67, 0, 105, 80,
	50, 0, 149, 151, 150, 134, 0, 0, 0, 0,
	0, 0, 0, 88, 89, 113, 0, 100, 0, 0,
	0, 0, 174, 106, 175, 147, 148, 152, 154, 153,
	166, 167, 164, 165, 168, 169, 170, 171, 172, 162,
	163, 156, 157, 155, 158, 160, 161, 0, 173, 0,
	0, 0, 0, 0, 81, 82, 0, 0, 0, 0,
	159, 0, 0, 0, 104, 0, 97, 93, 94, 95,
	90, 91, 0, 0, 0, 0, 0, 0, 98, 149,
	151, 150, 0, 129, 96, 92, 108, 0, 57, 0,
	0, 0, 0, 0, 99, 101, 0, 0, 0, 174,
	0, 175, 147, 148, 152, 154, 153, 166, 167, 164,
	165, 168, 169, 170, 171, 172, 162, 163, 156, 157,
	155, 158, 160, 161, 0, 173, 0, 0, 0, 0,
	0, 0, 0, 0, 149, 151, 150, 159, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 174, 668, 175, 147, 148, 152,
	154, 153, 166, 167, 164, 165, 168, 169, 170, 171,
	172, 162, 163, 156, 157, 155, 158, 160, 161, 0,
	173, 149, 151, 150, 0, 0, 0, 0, 0, 0,
	0, 0, 159, 0, 0, 0, 0, 0, 0, 0,
	0, 174, 0, 175, 147, 148, 152, 154, 153, 166,
	167, 164, 165, 168, 169, 170, 171, 172, 162, 163,
	156, 157, 155, 158, 160, 161, 0, 173, 149, 151,
	150, 0, 666, 0, 0, 0, 0, 0, 0, 159,
	0, 0, 0, 0, 0, 0, 0, 0, 174, 0,
	175, 147, 148, 152, 154, 153, 166, 167, 164, 165,
	168, 169, 170, 171, 172, 162, 163, 156, 157, 155,
	158, 160, 161, 0, 173, 149, 151, 150, 0, 0,
	0, 0, 0, 0, 0, 0, 159, 665, 0, 0,
	0, 0, 0, 0, 0, 174, 0, 175, 147, 148,
	152, 154, 153, 166, 167, 164, 165, 168, 169, 170,
	171, 172, 162, 163, 156, 157, 155, 158, 160, 161,
	0, 173, 149, 151, 150, 0, 0, 0, 0, 0,
	0, 0, 0, 159, 591, 0, 0, 0, 0, 0,
	0, 0, 174, 0, 175, 147, 148, 152, 154, 153,
	166, 167, 164, 165, 168, 169, 170, 171, 172, 162,
	163, 156, 157, 155, 158, 160, 161, 0, 173, 149,
	151, 150, 0, 0, 0, 0, 0, 0, 0, 0,
	159, 587, 0, 0, 0, 0, 0, 0, 0, 174,
	0, 175, 147, 148, 152, 154, 153, 166, 167, 164,
	165, 168, 169, 170, 171, 172, 162, 163, 156, 157,
	155, 158, 160, 161, 0, 173, 149, 151, 150, 0,
	0, 0, 0, 0, 0, 0, 0, 159, 562, 0,
	0, 0, 0, 0, 0, 0, 174, 0, 175, 147,
	148, 152, 154, 153, 166, 167, 164, 165, 168, 169,
	170, 171, 172, 162, 163, 156, 157, 155, 158, 160,
	161, 0, 173, 149, 151, 150, 0, 0, 0, 0,
	0, 0, 0, 356, 159, 0, 0, 0, 0, 0,
	0, 0, 0, 174, 0, 175, 147, 148, 152, 154,
	153, 166, 167, 164, 165, 168, 169, 170, 171, 172,
	162, 163, 156, 157, 155, 158, 160, 161, 0, 173,
	149, 151, 150, 0, 0, 0, 0, 0, 0, 0,
	146, 159, 0, 0, 0, 0, 0, 0, 0, 0,
	174, 0, 175, 147, 148, 152, 154, 153, 166, 167,
	164, 165, 168, 169, 170, 171, 172, 162, 163, 156,
	157, 155, 158, 160, 161, 0, 173, 149, 151, 150,
	0, 0, 0, 0, 0, 0, 689, 0, 159, 0,
	0, 0, 0, 0, 0, 0, 0, 174, 0, 175,
	147, 148, 152, 154, 153, 166, 167, 164, 165, 168,
	169, 170, 171, 172, 162, 163, 156, 157, 155, 158,
	160, 161, 0, 173, 149, 151, 150, 0, 0, 0,
	0, 0, 0, 661, 0, 159, 0, 0, 0, 0,
	0, 0, 0, 0, 174, 0, 175, 147, 148, 152,
	154, 153, 166, 167, 164, 165, 168, 169, 170, 171,
	172, 162, 163, 156, 157, 155, 158, 160, 161, 0,
	173, 149, 151, 150, 0, 0, 0, 0, 0, 0,
	660, 0, 159, 0, 0, 0, 0, 0, 0, 0,
	0, 174, 0, 175, 147, 148, 152, 154, 153, 166,
	167, 164, 165, 168, 169, 170, 171, 172, 162, 163,
	156, 157, 155, 158, 160, 161, 0, 173, 149, 151,
	150, 0, 0, 0, 0, 0, 0, 580, 0, 159,
	0, 0, 0, 0, 0, 0, 0, 0, 174, 0,
	175, 147, 148, 152, 154, 153, 166, 167, 164, 165,
	168, 169, 170, 171, 172, 162, 163, 156, 157, 155,
	158, 160, 161, 0, 173, 149, 151, 150, 0, 0,
	0, 0, 0, 0, 579, 0, 159, 0, 0, 0,
	0, 0, 0, 0, 0, 174, 0, 175, 147, 148,
	152, 154, 153, 166, 167, 164, 165, 168, 169, 170,
	171, 172, 162, 163, 156, 157, 155, 158, 160, 161,
	0, 173, 149, 151, 150, 0, 0, 0, 0, 0,
	0, 565, 0, 159, 0, 0, 0, 0, 0, 0,
	0, 0, 174, 0, 175, 147, 148, 152, 154, 153,
	166, 167, 164, 165, 168, 169, 170, 171, 172, 162,
	163, 156, 157, 155, 158, 160, 161, 0, 173, 149,
	151, 150, 0, 0, 0, 0, 0, 0, 560, 0,
	159, 0, 0, 0, 0, 0, 0, 0, 0, 174,
	0, 175, 147, 148, 152, 154, 153, 166, 167, 164,
	165, 168, 169, 170, 171, 172, 162, 163, 156, 157,
	155, 158, 160, 161, 0, 173, 149, 151, 150, 0,
	0, 0, 0, 0, 0, 535, 0, 159, 0, 0,
	0, 0, 0, 0, 0, 0, 174, 0, 175, 147,
	148, 152, 154, 153, 166, 167, 164, 165, 168, 169,
	170, 171, 172, 162, 163, 156, 157, 155, 158, 160,
	161, 0, 173, 149, 151, 150, 0, 0, 0, 0,
	0, 0, 531, 0, 159, 0, 0, 0, 0, 0,
	0, 0, 0, 174, 540, 175, 147, 148, 152, 154,
	153, 166, 167, 164, 165, 168, 169, 170, 171, 172,
	162, 163, 156, 157, 155, 158, 160, 161, 0, 173,
	0, 544, 149, 151, 150, 0, 0, 511, 0, 392,
	0, 159, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 174, 0, 175, 147, 148, 152, 154, 153,
	166, 167, 164, 165, 168, 169, 170, 171, 172, 162,
	163, 156, 157, 155, 158, 160, 161, 0, 173, 149,
	151, 150, 0, 0, 0, 0, 0, 0, 0, 0,
	159, 0, 0, 0, 0, 0, 0, 0, 0, 174,
	0, 175, 147, 148, 152, 154, 153, 166, 167, 164,
	165, 168, 169, 170, 171, 172, 162, 163, 156, 157,
	155, 158, 160, 161, 0, 173, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 159,
}
var yyPact = [...]int{

	-1000, -1000, 1337, -1000, -1000, -1000, -1000, -1000, -1000, 359,
	88, 411, 534, -1000, -1000, -1000, 350, 4555, 348, 347,
	5799, 5799, 5799, 11, 518, 5799, -1000, 6229, 346, 344,
	343, -1000, 72, 5799, 599, 703, 665, 600, 595, 590,
	583, 615, 622, 2492, -1000, -1000, 342, -1000, -1000, 77,
	5799, 4613, 4613, 5799, 5799, 5799, 5799, 5799, -1000, -1000,
	5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799, -1000, 5799,
	5799, 5799, -1000, -1000, -1000, 617, -1000, 379, 378, -1000,
	144, 341, 339, 5799, 5799, 330, 5799, 5799, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 523, 542,
	-1000, 55, 222, 222, 290, 5001, -1000, 360, 529, 217,
	529, -48, -1000, -1000, 178, 452, 335, 438, 529, -1000,
	-1000, -1000, -1000, 334, -1000, 728, 3130, 5799, 496, 239,
	5799, 5799, 177, 6889, -1000, 172, 170, 314, -1000, -1000,
	279, -1000, 727, 267, -1000, 6889, -1000, 5799, 5799, 5799,
	5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799,
	5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799,
	5799, 5799, 5799, 138, 5685, 5799, 4613, 5799, 534, -1000,
	6182, 163, -1000, 559, -1000, 551, -1000, 428, 71, 439,
	274, 4555, 245, 160, 702, 5571, 5799, 5799, 5799, 5799,
	5799, 5799, 5799, 5799, 5799, 5799, 5799, 5799, -1000, -1000,
	5799, 5799, 5799, 29, -1000, -1000, 617, 5799, -1000, -1000,
	624, 624, 674, 624, 6699, 624, 624, 624, 624, 624,
	624, 624, 624, 1178, 852, 1178, 5799, 1193, 1193, 222,
	-1000, 374, 175, 222, -1000, -1000, 5799, 5799, 6889, 6889,
	5799, 6889, 6889, 501, -1000, 520, -1000, 479, 5457, 4613,
	194, 488, 5799, -1000, -1000, 5229, -1000, 5001, -56, 756,
	-1000, -1000, 6842, 4613, 240, 546, 360, 156, 360, -1000,
	-1000, 1030, -1000, 145, 237, 434, 529, -1000, 408, 168,
	543, 431, -1000, -1000, 534, 5799, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, 238, 6652, 236, 132, 755, 6889, 6605,
	-1000, -1000, -1000, -1000, 11, -1000, 518, 5799, -1000, 5799,
	1646, 1325, 3445, 1178, 1015, 1809, 2131, 1969, 653, 653,
	653, 674, 624, 674, 674, 1977, 1977, 2289, 2289, 2289,
	2289, 2289, 1188, 1188, 1188, 1188, -1000, 6793, 5799, 1485,
	751, -1000, -1000, 6746, 233, 2967, -1000, -1000, 223, 428,
	422, 398, -1000, 65, 398, 5799, -1000, 5799, -1000, -1000,
	1178, 5799, 1178, 1178, 1178, 1178, 1178, 1178, 1178, 1178,
	1178, 1178, 1178, 1178, 6558, -57, 6135, 222, -1000, 5799,
	-1000, 6511, -1000, 5799, -61, -1000, 222, -1000, -1000, -1000,
	5799, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, 222, -1000, -1000, -1000,
	11, 5799, 5799, 29, 11, 428, 749, -1000, 6889, 6464,
	6417, -1000, -1000, -1000, -1000, -1000, 630, 532, 6088, 52,
	-39, -1000, 6041, -1000, 748, -1000, 6889, 5799, 216, -1000,
	5001, 5115, -1000, 5001, -1000, -1000, 867, -1000, -1000, -1000,
	149, 418, -1000, 529, 388, 570, -1000, 143, -1000, 6889,
	213, 4392, 5799, 5799, 5799, 81, -1000, -1000, 6889, -1000,
	5799, 1485, 209, 4613, 221, 4229, -1000, 356, 422, 21,
	398, -1000, 707, -1000, 740, -1000, 6370, 6323, 2804, 2131,
	4066, -1000, -1000, -1000, 5994, -1000, 1178, -1000, -1000, 5939,
	-1000, -1000, -62, 5862, -1000, -1000, 422, 204, 5799, -1000,
	-1000, -66, -1000, -1000, 507, -1000, -1000, -1000, -1000, 5799,
	-1000, -1000, 203, 5343, 6889, -1000, -1000, 6889, 4613, 220,
	202, -1000, 529, 61, 743, -1000, -1000, 529, 570, 130,
	-1000, -1000, -1000, 6276, 128, 6889, -1000, 125, 123, 1485,
	122, -1000, 320, -1000, 4613, 195, 5001, -1000, -1000, -1000,
	455, 201, 745, -1000, 666, -1000, -1000, 393, -1000, -1000,
	-1000, -17, -1000, 740, -1000, -1000, 509, 464, 398, 700,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 524, 398,
	4555, 698, 119, -1000, -1000, -1000, -1000, -1000, -1000, -20,
	-1000, -1000, -1000, -1000, 373, -1000, -1000, -1000, 5001, -1000,
	741, -1000, 529, -40, 570, -1000, 743, -1000, 2641, 118,
	5799, 31, -1000, 553, -1000, -1000, 3740, 221, -1000, 5001,
	-67, 2478, -1000, 192, -24, 694, 356, 234, -1000, -1000,
	-1000, 367, 124, -1000, 726, 4718, 665, 91, -1000, -1000,
	-1000, -1000, -1000, -1000, 3293, -1000, -41, 200, -43, 529,
	741, -1000, -1000, -44, 109, -1000, 193, -1000, 5799, 191,
	17, 104, 541, -1000, -1000, -1000, 188, 187, -1000, 101,
	398, -1000, -32, 356, -1000, 511, -1000, 358, -1000, -1000,
	509, 5799, 120, -1000, 721, 4718, -1000, -1000, 3595, 3293,
	108, -1000, -1000, -1000, -1000, -45, -1000, -1000, 3903, 420,
	-1000, -1000, -1000, -1000, -1000, 100, 2315, 3740, -1000, -1000,
	575, -1000, 2152, -1000, -1000, 714, -1000, -1000, 6889, -1000,
	4718, 5799, 110, -1000, 3456, -1000, 96, 95, 450, 475,
	362, -1000, 239, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	3293, -1000, 94, -1000, 169, 398, -1000, 1989, 5799, -1000,
	6889, 356, -1000, -1000, -1000, -1000, 398, 4857, 4718, 1826,
	3293, -1000, -35, -1000, -1000, 6889, 78, 740, -1000, -1000,
	4718, -1000, 75, -1000, 694, -1000, -1000, 1663, -51, -1000,
	-1000, -1000, -1000, 1500, -1000,
}
var yyPgo = [...]int{

	0, 723, 907, 879, 18, 8, 878, 2, 877, 25,
	5, 77, 75, 876, 1, 869, 50, 45, 868, 3,
	13, 30, 4, 866, 20, 0, 865, 862, 225, 35,
	861, 860, 859, 857, 856, 24, 852, 851, 849, 27,
	82, 848, 73, 847, 74, 844, 69, 840, 41, 19,
	32, 52, 839, 838, 11, 81, 79, 835, 834, 833,
	832, 15, 828, 826, 825, 7, 823, 14, 822, 10,
	819, 6, 818, 817, 9, 816, 815, 813, 812, 809,
	808, 582, 80, 806, 42, 101, 805, 804, 39, 803,
	60, 751, 801, 800, 33, 31, 574, 28, 16, 76,
	44, 43, 798, 40, 49, 89, 797, 29, 796, 794,
	83, 793, 791, 96, 90, 790, 789, 773, 38, 766,
	17, 12,
}
var yyR1 = [...]int{

	0, 119, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 6,
	6, 6, 6, 6, 6, 6, 7, 7, 9, 9,
	10, 10, 10, 11, 11, 8, 8, 8, 8, 8,
	8, 8, 8, 8, 8, 8, 8, 8, 8, 91,
	91, 92, 92, 93, 93, 94, 94, 95, 95, 96,
	96, 97, 97, 98, 98, 99, 99, 14, 14, 13,
	13, 13, 13, 13, 13, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 12,
	12, 12, 12, 12, 12, 12, 12, 12, 12, 58,
	58, 59, 59, 60, 60, 55, 55, 56, 57, 57,
	30, 30, 31, 31, 32, 32, 33, 33, 34, 34,
	35, 35, 36, 36, 111, 112, 112, 113, 113, 38,
	38, 38, 38, 39, 39, 39, 121, 121, 37, 37,
	49, 49, 49, 49, 50, 51, 51, 52, 52, 53,
	53, 53, 53, 53, 53, 54, 54, 41, 41, 42,
	43, 43, 44, 44, 45, 45, 46, 47, 47, 48,
	120, 120, 16, 16, 15, 15, 1, 1, 100, 101,
	103, 103, 102, 102, 104, 104, 61, 61, 62, 62,
	62, 62, 71, 71, 72, 72, 72, 73, 73, 74,
	74, 75, 76, 76, 76, 76, 77, 77, 78, 79,
	79, 63, 63, 68, 68, 69, 70, 70, 64, 64,
	65, 65, 65, 65, 65, 65, 66, 66, 67, 67,
	17, 22, 22, 23, 23, 24, 24, 18, 18, 4,
	4, 2, 2, 3, 3, 20, 20, 21, 21, 21,
	19, 19, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 80, 80, 80, 80, 80, 80, 80, 80,
	80, 80, 80, 80, 80, 80, 80, 80, 81, 81,
	81, 81, 82, 82, 82, 82, 82, 82, 82, 83,
	83, 83, 83, 116, 116, 116, 116, 116, 116, 116,
	117, 117, 118, 84, 84, 84, 85, 85, 114, 114,
	86, 87, 87, 87, 108, 108, 108, 88, 88, 88,
	25, 25, 40, 40, 27, 27, 27, 27, 27, 27,
	109, 109, 109, 109, 110, 110, 110, 105, 105, 106,
	106, 107, 107, 28, 28, 28, 90, 90, 90, 29,
	29, 29, 89, 89, 115, 115, 115, 115, 115, 115,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 3,
	1, 2, 3, 2, 0, 1, 1, 1, 1, 1,
	4, 3, 5, 4, 3, 4, 3, 4, 3, 1,
	1, 6, 7, 6, 7, 3, 1, 3, 1, 3,
	1, 1, 2, 1, 3, 1, 2, 2, 0, 1,
	1, 1, 1, 1, 4, 3, 1, 1, 5, 7,
	9, 5, 3, 3, 3, 3, 3, 3, 1, 2,
	6, 7, 9, 5, 1, 6, 3, 3, 2, 0,
	9, 1, 3, 0, 4, 3, 1, 3, 1, 4,
	5, 6, 1, 3, 6, 7, 3, 6, 1, 4,
	0, 1, 3, 1, 7, 3, 2, 0, 1, 3,
	4, 4, 5, 0, 5, 4, 1, 1, 1, 4,
	1, 2, 4, 3, 1, 0, 1, 3, 1, 3,
	1, 4, 2, 6, 4, 1, 4, 3, 1, 1,
	3, 1, 1, 3, 3, 1, 1, 1, 3, 1,
	0, 1, 8, 7, 1, 2, 1, 1, 5, 6,
	0, 2, 0, 2, 0, 2, 2, 0, 3, 4,
	3, 9, 1, 3, 1, 2, 3, 1, 2, 2,
	2, 3, 3, 3, 4, 3, 1, 1, 3, 1,
	3, 1, 1, 3, 1, 3, 0, 1, 1, 2,
	1, 1, 1, 1, 1, 1, 3, 1, 1, 3,
	10, 1, 0, 1, 3, 4, 6, 0, 1, 0,
	1, 0, 1, 0, 1, 1, 2, 1, 1, 1,
	0, 2, 3, 4, 2, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 2, 2, 2,
	2, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 2, 2,
	2, 2, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 1, 5, 4, 3, 1, 2, 2,
	2, 2, 2, 2, 2, 2, 1, 2, 1, 2,
	4, 2, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 3, 2, 3, 3, 1, 1, 2, 2,
	1, 2, 1, 4, 3, 3, 3, 6, 3, 1,
	1, 2, 1, 5, 4, 2, 2, 4, 2, 2,
	1, 3, 1, 1, 3, 3, 1, 1, 1, 1,
	1, 1, 3, 1, 1, 3, 1, 4, 3, 1,
	1, 1, 0, 1, 1, 4, 4, 4, 4, 1,
	2, 4, 4, 2, 1, 3, 1, 2, 4, 1,
	3, 1, 2, 1, 1, 3, 1, 3, 1, 1,
	4, 2, 3, 3, 1, 4, 4, 3, 3, 3,
}
var yyChk = [...]int{

	-1000, -119, -11, -8, -12, -17, -16, -100, -101, 127,
	154, 120, 114, 162, -31, -33, 97, 96, 99, 106,
	110, 111, 115, 122, 76, 95, 90, -25, 124, 101,
	103, 161, 116, 119, 112, 86, 113, -15, 128, 129,
	130, -30, -32, -28, -26, -1, 83, -27, -89, -87,
	71, 58, 59, 49, 50, 55, 57, 159, -112, -116,
	60, 61, 62, 63, 64, 65, 66, 67, -80, 13,
	14, 16, 77, 78, -29, -84, -109, -85, -86, -88,
	70, 125, 126, 4, 5, 6, 7, 8, 84, 85,
	141, 142, 156, 138, 139, 140, 155, 137, 149, 165,
	88, 166, -10, -108, 135, 69, 94, -9, 157, 159,
	157, -9, 162, 86, -93, -91, -96, -9, 157, 113,
	114, -99, -98, -55, -56, 86, -14, 159, -12, 154,
	159, 159, -40, -25, 76, -40, -40, -41, -42, -29,
	-43, -44, 88, -45, -46, -25, 161, 33, 34, 10,
	12, 11, 35, 37, 36, 51, 49, 50, 52, 68,
	53, 54, 47, 48, 40, 41, 38, 39, 42, 43,
	44, 45, 46, 56, 30, 32, 159, 159, 159, 162,
	-25, 86, 31, -4, 37, 128, -1, 86, 86, 86,
	73, 74, 73, 75, 74, 17, 18, 19, 20, 29,
	21, 22, 23, 24, 25, 26, 27, 28, 58, 59,
	159, 69, 162, 133, -25, -28, -84, 159, -88, -28,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, 69, 153, 153, -114,
	-111, -85, -115, 128, -10, -29, 159, 159, -25, -25,
	159, -25, -25, 93, 150, -81, -82, 88, 151, 152,
	-81, 93, 162, -29, -105, 159, -105, 159, -50, -52,
	-51, -53, -25, 37, 134, 157, -9, 160, -9, 161,
	162, -11, 161, -92, -96, -9, 157, 161, 9, 157,
	105, -9, -98, 161, 9, 17, -13, 163, -12, -17,
	-16, -100, -101, 127, -25, 97, -35, -36, -25, -25,
	161, 161, 161, 161, 9, 161, 9, 17, 161, 9,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -25, -114, -25, 31, -25,
	-47, -48, -28, -25, -55, -14, 161, 161, 86, 86,
	-103, 131, 162, -102, 131, 159, -12, 159, 161, 31,
	-25, 37, -25, -25, -25, -25, -25, -25, -25, -25,
	-25, -25, -25, -25, -25, -40, -25, -90, 86, 162,
	-29, -25, 160, 15, -40, -7, -110, -29, 86, -6,
	162, -5, 76, 77, 78, 79, 80, 81, 4, 5,
	6, 7, 8, 10, 11, 12, 56, 70, 71, 82,
	83, 73, 74, 75, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 111, 112, 113, 114,
	115, 13, 14, 134, 106, 107, 108, 109, 110, 135,
	136, 131, 132, 154, 129, 130, 128, 137, 138, 140,
	139, 141, 142, 156, 155, -7, -110, -29, -113, -105,
	153, 69, 162, 133, 153, -113, -117, -118, -25, -25,
	-25, 150, -82, 150, -82, 93, 69, 133, -25, 87,
	-28, 165, -25, 160, -106, -107, -25, 158, -50, 164,
	9, 15, -28, 159, 86, 161, -11, 163, 161, 161,
	157, -9, -99, 157, -9, 162, 86, 157, -56, -25,
	159, 160, 159, 161, 9, 160, -42, -44, -25, -46,
	31, -25, -120, 9, 105, 160, 163, 159, -103, -104,
	132, -10, -61, 162, -71, -10, -25, -25, -14, -25,
	160, 164, 163, -105, -25, 160, -25, 164, -105, -25,
	-105, -29, -40, -25, -90, -29, -103, -120, 9, 160,
	160, -83, 86, 89, 50, 88, 86, 163, 163, 69,
	163, 163, -120, 9, -25, 160, -51, -25, 37, 134,
	-50, 163, 162, 157, -94, -97, -98, -91, 162, 160,
	-34, -12, 31, -25, -35, -25, -38, 162, 31, -25,
	160, -48, -49, -28, 37, 134, 69, -57, -12, 31,
	-58, -22, -23, -24, -18, -20, -21, 30, -10, 135,
	136, -104, 162, -71, 163, -62, -63, -70, 120, -64,
	123, -65, 81, 80, 79, 76, 77, 78, -61, 9,
	160, 160, 75, -12, 31, 163, 163, 164, 163, -104,
	160, -118, 164, 89, -25, 160, -107, -28, 159, 160,
	-95, -98, 162, -120, 9, -98, -94, 161, -14, 160,
	161, -39, 161, -39, 161, 161, 160, 15, -28, 159,
	-50, -14, -60, 117, 118, 160, 9, -2, 37, -21,
	162, -61, -66, -67, 88, 114, 113, -71, -65, 163,
	-10, -12, 31, 161, -14, 162, 164, -50, -120, 9,
	-95, 163, -97, -120, 98, 161, -35, 163, 108, 109,
	-39, 107, -39, -54, -12, 31, -49, -50, 164, 104,
	159, 162, -19, 31, -24, -3, 158, -61, 163, 161,
	9, 17, -68, -69, -7, -4, -72, 161, 162, -14,
	-61, 163, 160, 163, -98, -120, 163, 161, 160, -25,
	-121, 31, 161, 163, 161, 107, -14, 160, 160, 161,
	-59, -10, -14, 162, -20, 88, 163, -67, -25, 161,
	9, 17, -7, 163, -73, -74, -75, -76, -78, -77,
	-10, -7, 154, 86, 163, 163, -37, -12, 31, -121,
	-14, 161, 102, -54, 88, 35, 163, -14, 17, -69,
	-25, 159, 163, -74, 161, 161, 121, 105, 153, -14,
	-14, 161, 160, -10, 163, -25, -22, -71, 86, -5,
	-65, -7, 100, 162, 160, -7, 161, -14, -19, 163,
	-79, 161, 162, -14, 163,
}
var yyDef = [...]int{

	84, -2, 1, 83, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 118, 126, 127, 0, 0, 0, 0,
	432, 432, 432, 0, 416, 0, 138, 0, 0, 0,
	0, 144, 0, 0, 0, 78, 289, 0, 0, 0,
	0, 162, 0, -2, 431, 224, 0, -2, 454, 420,
	0, 0, 0, 0, 0, 0, 0, 0, 353, 357,
	0, 0, 0, 0, 0, 0, 0, 0, 366, 0,
	368, 0, 226, 227, 434, 387, 439, 0, 0, -2,
	0, 0, 0, 0, 0, 0, 0, 0, 372, 373,
	374, 375, 376, 377, 378, 379, 380, 381, 0, 0,
	459, 0, -2, 0, 0, 195, 429, 80, 0, 0,
	0, 0, 84, 78, 0, 0, 0, 113, 0, 99,
	100, 110, 115, 0, 156, 0, 0, 0, 0, 0,
	170, 0, 0, 433, 416, 0, 0, 0, 208, 209,
	0, 211, 212, 0, 215, 216, 139, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 118,
	0, 0, 148, 0, 290, 0, 225, 230, 0, 232,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 317, 319,
	0, 432, 0, 0, 304, -2, 0, 0, -2, -2,
	338, 339, 340, 341, 0, 358, 359, 360, 361, 362,
	363, 364, 365, 367, 369, 371, 432, 0, 0, 177,
	176, 418, 419, 177, 417, 464, 0, 0, 405, 406,
	0, 408, 409, 0, 383, 0, 390, 392, 0, 0,
	0, 0, 0, 461, 440, 0, 443, 195, 0, 194,
	198, 196, 200, 0, 0, 0, 81, 0, 82, 91,
	84, 0, 94, 0, 0, 113, 0, 96, 0, 0,
	0, 113, 116, 98, 0, 0, 117, 125, 119, 120,
	121, 122, 123, 0, 0, 0, 0, 171, 173, 0,
	132, 133, 134, 135, 0, 136, 0, 0, 137, 0,
	321, 322, 323, 324, 325, 326, 327, 328, 329, 330,
	331, 332, 333, 334, 335, 336, 337, -2, -2, -2,
	-2, -2, -2, -2, -2, -2, 351, 0, 0, 356,
	220, 217, -2, 0, 0, 0, 146, 147, 0, 230,
	234, 0, 237, 0, 0, 0, 163, 0, 166, 118,
	302, 0, 305, 306, 307, 308, 309, 310, 311, 312,
	313, 314, 315, 316, 0, 0, 0, 455, 456, 0,
	458, 0, -2, 0, 0, -2, 0, -2, 76, 77,
	0, 69, 70, 71, 72, 73, 74, 75, 2, 3,
	4, 5, 6, 7, 8, 9, 10, 11, 12, 13,
	14, 15, 16, 17, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 30, 31, 32, 33,
	34, 35, 36, 37, 38, 39, 40, 41, 42, 43,
	44, 45, 46, 47, 48, 49, 50, 51, 52, 53,
	54, 55, 56, 57, 58, 59, 60, 61, 62, 63,
	64, 65, 66, 67, 68, -2, 0, -2, 175, 178,
	0, 432, 0, 0, 0, 230, 220, 410, 412, 0,
	0, 382, 391, 385, 388, 389, 0, 0, 0, 0,
	421, 384, 0, 447, 220, 449, 451, 0, 0, 428,
	195, 0, -2, 195, 79, 90, 0, 93, 95, 97,
	0, 113, 109, 0, 113, 0, 114, 0, 155, 157,
	0, 0, 0, 170, 0, 0, 207, 210, 213, 214,
	0, 355, 0, 221, 0, 0, 149, -2, 234, 0,
	0, 231, 266, 237, 233, 242, 0, 0, 0, 303,
	0, 435, 437, 438, 0, -2, 370, 436, 441, 0,
	442, 468, 0, 0, 467, 469, 234, 0, 221, 404,
	407, 0, 399, 400, 0, 402, 394, 395, 396, 0,
	398, 460, 0, 221, 452, 427, 197, 199, 0, 0,
	0, 92, 0, 0, 220, 106, 111, 0, 0, 0,
	128, 168, 118, 0, 0, 172, 131, 183, 183, 354,
	0, 218, 0, -2, 0, 0, 195, 143, 158, 118,
	153, 0, 281, 283, 291, 288, 295, 0, 297, 298,
	299, 0, 237, 235, 228, 236, 0, 0, 0, -2,
	262, 268, 270, 271, 272, 273, 274, 275, 266, 0,
	0, 0, 0, 160, 118, 457, 445, 465, 466, 0,
	403, 411, 393, 401, 0, 448, 450, -2, 195, 204,
	220, 108, 0, 0, 221, 112, 220, 124, 0, 0,
	170, 0, 183, 0, 183, 140, 0, 0, -2, 195,
	0, 0, 145, 0, 0, 300, 287, 293, 292, 296,
	237, 266, 0, 277, 278, 0, 289, 0, 269, 229,
	243, 161, 118, 167, 164, 237, 0, 0, 0, 221,
	220, 103, 105, 0, 0, 129, 0, 179, 0, 0,
	0, 0, 0, 141, 205, 118, 0, 0, -2, 0,
	0, 118, 0, 0, 284, 0, 294, 266, 223, 238,
	0, 0, 0, 264, 0, 0, 240, 244, 0, 165,
	266, 397, 203, 101, 107, 0, 104, 169, 0, 0,
	118, 186, 187, 180, 181, 0, 0, 0, 192, 159,
	0, 151, 0, 118, 301, 285, 222, 276, 279, 239,
	0, 0, 0, 245, 0, 247, 0, 0, 257, 0,
	0, 256, 57, -2, 174, 102, 130, 188, 118, 118,
	185, 182, 0, 142, 0, 0, 154, 0, 0, 263,
	265, -2, 246, 248, 249, 250, 0, 0, 0, 0,
	184, 206, 0, 152, 280, 286, 0, 251, 252, 253,
	255, 258, 0, 118, 300, 254, 189, 0, 0, 150,
	241, 259, 118, 0, 260,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 165, 3, 166, 54, 37, 3,
	159, 160, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 161,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 164, 36, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 162, 35, 163, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:317
		{
			fmt.Println(yyDollar[1].node)
		}
	case 2:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 5:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:321
		{
			yyVAL.value = yyDollar[1].token
		}
	case 10:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 11:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 12:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 13:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 14:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 15:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 16:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 18:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 21:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:322
		{
			yyVAL.value = yyDollar[1].token
		}
	case 22:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 27:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 28:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 29:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 30:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:323
		{
			yyVAL.value = yyDollar[1].token
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 33:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 34:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 35:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 36:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 37:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 38:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 39:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:324
		{
			yyVAL.value = yyDollar[1].token
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 47:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 48:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 49:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 50:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 51:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:325
		{
			yyVAL.value = yyDollar[1].token
		}
	case 53:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 54:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 55:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 57:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 58:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:326
		{
			yyVAL.value = yyDollar[1].token
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 67:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 68:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:327
		{
			yyVAL.value = yyDollar[1].token
		}
	case 69:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:331
		{
			yyVAL.value = yyDollar[1].value
		}
	case 70:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 72:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 73:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 74:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:332
		{
			yyVAL.value = yyDollar[1].token
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:336
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].token)
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:337
		{
			yyVAL.node = Node("identifier").attribute("value", yyDollar[1].value)
		}
	case 78:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:341
		{
			yyVAL.node = Node("NamespaceParts").append(Node(yyDollar[1].token))
		}
	case 79:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:342
		{
			yyVAL.node = yyDollar[1].node.append(Node(yyDollar[3].token))
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:346
		{
			yyVAL.node = Node("Name").append(yyDollar[1].node)
		}
	case 81:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:347
		{
			yyVAL.node = Node("Name").append(yyDollar[2].node).attribute("FullyQualified", "true")
		}
	case 82:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:348
		{
			yyVAL.node = Node("Name").append(yyDollar[3].node).attribute("Relative", "true")
		}
	case 83:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:352
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 84:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:353
		{
			yyVAL.node = Node("Statements")
		}
	case 85:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:357
		{
			yyVAL.node = yyDollar[1].node
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:358
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:359
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:360
		{
			yyVAL.node = yyDollar[1].node
		}
	case 89:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:361
		{
			yyVAL.node = yyDollar[1].node
		}
	case 90:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:362
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 91:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:363
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node)
		}
	case 92:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:365
		{
			yyVAL.node = Node("Namespace").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 93:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:366
		{
			yyVAL.node = Node("Namespace").append(yyDollar[3].node)
		}
	case 94:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:367
		{
			yyVAL.node = yyDollar[2].node
		}
	case 95:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:368
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:369
		{
			yyVAL.node = yyDollar[2].node
		}
	case 97:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:370
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[2].node)
		}
	case 98:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:371
		{
			yyVAL.node = yyDollar[2].node
		}
	case 99:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:375
		{
			yyVAL.node = Node("FuncUseType")
		}
	case 100:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:376
		{
			yyVAL.node = Node("ConstUseType")
		}
	case 101:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:381
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 102:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:383
		{
			yyVAL.node = Node("GroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 103:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:388
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 104:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:390
		{
			yyVAL.node = Node("MixedGroupUse").append(yyDollar[2].node).append(yyDollar[5].node)
		}
	case 105:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:395
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 106:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:396
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:400
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 108:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:401
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 109:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:404
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 110:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:405
		{
			yyVAL.node = Node("UseList").append(yyDollar[1].node)
		}
	case 111:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:408
		{
			yyVAL.node = yyDollar[1].node
		}
	case 112:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:409
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 113:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:412
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node)
		}
	case 114:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:413
		{
			yyVAL.node = Node("UseElem").append(yyDollar[1].node).append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 115:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:416
		{
			yyVAL.node = yyDollar[1].node
		}
	case 116:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:417
		{
			yyVAL.node = yyDollar[2].node
		}
	case 117:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:421
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 118:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:422
		{
			yyVAL.node = Node("stmt")
		}
	case 119:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:426
		{
			yyVAL.node = yyDollar[1].node
		}
	case 120:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:427
		{
			yyVAL.node = yyDollar[1].node
		}
	case 121:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:428
		{
			yyVAL.node = yyDollar[1].node
		}
	case 122:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:429
		{
			yyVAL.node = yyDollar[1].node
		}
	case 123:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:430
		{
			yyVAL.node = yyDollar[1].node
		}
	case 124:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:431
		{
			yyVAL.node = Node("THaltCompiler")
		}
	case 125:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:434
		{
			yyVAL.node = yyDollar[2].node
		}
	case 126:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:435
		{
			yyVAL.node = yyDollar[1].node
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:436
		{
			yyVAL.node = yyDollar[1].node
		}
	case 128:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:438
		{
			yyVAL.node = Node("While").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("stmt").append(yyDollar[5].node))
		}
	case 129:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:444
		{
			yyVAL.node = Node("DoWhile").
				append(Node("expr").append(yyDollar[5].node)).
				append(Node("stmt").append(yyDollar[2].node))
		}
	case 130:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:450
		{
			yyVAL.node = Node("For").
				append(Node("expr1").append(yyDollar[3].node)).
				append(Node("expr2").append(yyDollar[5].node)).
				append(Node("expr3").append(yyDollar[7].node)).
				append(Node("stmt").append(yyDollar[9].node))
		}
	case 131:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:457
		{
			yyVAL.node = Node("Switch").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node)
		}
	case 132:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:458
		{
			yyVAL.node = Node("Break").append(yyDollar[2].node)
		}
	case 133:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:459
		{
			yyVAL.node = Node("Continue").append(yyDollar[2].node)
		}
	case 134:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:460
		{
			yyVAL.node = Node("Return").append(yyDollar[2].node)
		}
	case 135:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:461
		{
			yyVAL.node = yyDollar[2].node
		}
	case 136:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:462
		{
			yyVAL.node = yyDollar[2].node
		}
	case 137:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:463
		{
			yyVAL.node = yyDollar[2].node
		}
	case 138:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:464
		{
			yyVAL.node = Node("Echo").append(Node("InlineHtml").attribute("value", yyDollar[1].token))
		}
	case 139:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:465
		{
			yyVAL.node = yyDollar[1].node
		}
	case 140:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:467
		{
			yyVAL.node = Node("Unset").append(yyDollar[3].node)
		}
	case 141:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:469
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachVariable").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 142:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:476
		{
			yyVAL.node = Node("Foreach").
				append(Node("expr").append(yyDollar[3].node)).
				append(Node("ForeachKey").append(yyDollar[5].node)).
				append(Node("ForeachVariable").append(yyDollar[7].node)).
				append(yyDollar[9].node)
		}
	case 143:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:483
		{
			yyVAL.node = Node("Declare").append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 144:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:484
		{
			yyVAL.node = Node("")
		}
	case 145:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:486
		{
			yyVAL.node = Node("Try").
				append(yyDollar[3].node).
				append(yyDollar[5].node).
				append(yyDollar[6].node)
		}
	case 146:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:492
		{
			yyVAL.node = Node("Throw").append(yyDollar[2].node)
		}
	case 147:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:493
		{
			yyVAL.node = Node("GoTo").attribute("Label", yyDollar[2].token)
		}
	case 148:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:494
		{
			yyVAL.node = Node("Label").attribute("name", yyDollar[1].token)
		}
	case 149:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:497
		{
			yyVAL.node = Node("CatchList")
		}
	case 150:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:499
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[4].node).append(Node("Variable").attribute("name", yyDollar[5].token)).append(yyDollar[8].node)
		}
	case 151:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:502
		{
			yyVAL.node = Node("CatchNameList").append(yyDollar[1].node)
		}
	case 152:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:503
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 153:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:507
		{
			yyVAL.node = Node("")
		}
	case 154:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:508
		{
			yyVAL.node = Node("Finnaly").append(yyDollar[3].node)
		}
	case 155:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:512
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:513
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 157:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:517
		{
			yyVAL.node = Node("Const").attribute("name", yyDollar[1].token).append(yyDollar[3].node)
		}
	case 158:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:521
		{
			yyVAL.node = yyDollar[1].node
		}
	case 159:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:522
		{
			yyVAL.node = yyDollar[2].node
		}
	case 160:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:527
		{
			yyVAL.node = Node("If").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[5].node))
		}
	case 161:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:531
		{
			yyVAL.node = yyDollar[1].node.append(Node("ElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[6].node)))
		}
	case 162:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:537
		{
			yyVAL.node = yyDollar[1].node
		}
	case 163:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:539
		{
			yyVAL.node = yyDollar[1].node.append(Node("Else").append(Node("stmt").append(yyDollar[3].node)))
		}
	case 164:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:546
		{
			yyVAL.node = Node("AltIf").append(Node("expr").append(yyDollar[3].node)).append(Node("stmt").append(yyDollar[6].node))
		}
	case 165:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:550
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElseIf").append(Node("expr").append(yyDollar[4].node)).append(Node("stmt").append(yyDollar[7].node)))
		}
	case 166:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:556
		{
			yyVAL.node = yyDollar[1].node
		}
	case 167:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:558
		{
			yyVAL.node = yyDollar[1].node.append(Node("AltElse").append(Node("stmt").append(yyDollar[4].node)))
		}
	case 168:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:564
		{
			yyVAL.node = yyDollar[1].node
		}
	case 169:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:565
		{
			yyVAL.node = yyDollar[2].node
		}
	case 170:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:569
		{
			yyVAL.node = Node("")
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:570
		{
			yyVAL.node = yyDollar[1].node
		}
	case 172:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:573
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 173:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:574
		{
			yyVAL.node = Node("ExpressionList").append(yyDollar[1].node)
		}
	case 174:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:579
		{
			yyVAL.node = Node("AnonymousClass").
				attribute("name", yyDollar[1].token).
				append(yyDollar[2].node).
				append(yyDollar[3].node).
				append(yyDollar[4].node).
				append(yyDollar[6].node)
		}
	case 175:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:590
		{
			yyVAL.node = Node("New").append(yyDollar[2].node).append(yyDollar[3].node)
		}
	case 176:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:591
		{
			yyVAL.node = Node("New").append(yyDollar[2].node)
		}
	case 177:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:595
		{
			yyVAL.node = Node("ArgumentList")
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:596
		{
			yyVAL.node = yyDollar[1].node
		}
	case 179:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:600
		{
			yyVAL.node = yyDollar[2].node
		}
	case 180:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:601
		{
			yyVAL.node = yyDollar[3].node
		}
	case 181:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:602
		{
			yyVAL.node = yyDollar[2].node
		}
	case 182:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:603
		{
			yyVAL.node = yyDollar[3].node
		}
	case 183:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:607
		{
			yyVAL.node = Node("CaseList")
		}
	case 184:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:609
		{
			yyVAL.node = yyDollar[1].node.append(Node("Case").append(Node("expr").append(yyDollar[3].node)).append(yyDollar[5].node))
		}
	case 185:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:613
		{
			yyVAL.node = yyDollar[1].node.append(Node("Default").append(yyDollar[4].node))
		}
	case 188:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:624
		{
			yyVAL.node = yyDollar[1].node
		}
	case 189:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:625
		{
			yyVAL.node = yyDollar[2].node
		}
	case 190:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:629
		{
			yyVAL.node = yyDollar[1].node
		}
	case 191:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:630
		{
			yyVAL.node = Node("Ref").append(yyDollar[2].node)
		}
	case 192:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:631
		{
			yyVAL.node = Node("List").append(yyDollar[3].node)
		}
	case 193:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:632
		{
			yyVAL.node = Node("ShortList").append(yyDollar[2].node)
		}
	case 194:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:636
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 195:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:640
		{
			yyVAL.node = Node("")
		}
	case 196:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:641
		{
			yyVAL.node = yyDollar[1].node
		}
	case 197:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:646
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:647
		{
			yyVAL.node = Node("ArrayPairList").append(yyDollar[1].node)
		}
	case 199:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:651
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 200:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:652
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node)
		}
	case 201:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:653
		{
			yyVAL.node = Node("ArrayElement").append(yyDollar[1].node).append(Node("Ref").append(yyDollar[4].node))
		}
	case 202:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:654
		{
			yyVAL.node = Node("ArrayElement").append(Node("Ref").append(yyDollar[2].node))
		}
	case 203:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:656
		{
			yyVAL.node = Node("ArrayElement").
				append(yyDollar[1].node).
				append(Node("ArrayList").append(yyDollar[5].node))
		}
	case 204:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:662
		{
			yyVAL.node = Node("ArrayElement").
				append(Node("ArrayList").append(yyDollar[3].node))
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:669
		{
			yyVAL.node = yyDollar[1].node
		}
	case 206:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:670
		{
			yyVAL.node = yyDollar[2].node
		}
	case 207:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:674
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 208:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:675
		{
			yyVAL.node = Node("GlobalVarList").append(yyDollar[1].node)
		}
	case 209:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:679
		{
			yyVAL.node = yyDollar[1].node
		}
	case 210:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:683
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 211:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:684
		{
			yyVAL.node = Node("StaticVarList").append(yyDollar[1].node)
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:688
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token)
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:689
		{
			yyVAL.node = Node("StaticVariable").attribute("Name", yyDollar[1].token).append(Node("expr").append(yyDollar[3].node))
		}
	case 214:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:693
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 215:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:694
		{
			yyVAL.node = Node("EchoList").append(yyDollar[1].node)
		}
	case 216:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:698
		{
			yyVAL.node = Node("Echo").append(yyDollar[1].node)
		}
	case 217:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:702
		{
			yyVAL.node = Node("UnsetVariablesList").append(yyDollar[1].node)
		}
	case 218:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:703
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 219:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:707
		{
			yyVAL.node = yyDollar[1].node
		}
	case 222:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line parser.y:717
		{
			yyVAL.node = Node("Class").
				attribute("name", yyDollar[3].token).
				append(yyDollar[1].node).
				append(Node("Extends").append(yyDollar[4].node)).
				append(Node("Implements").append(yyDollar[5].node)).
				append(yyDollar[7].node)
		}
	case 223:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser.y:726
		{
			yyVAL.node = Node("Class").
				attribute("name", yyDollar[2].token).
				append(Node("Extends").append(yyDollar[3].node)).
				append(Node("Implements").append(yyDollar[4].node)).
				append(yyDollar[6].node)
		}
	case 224:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:736
		{
			yyVAL.node = Node("Class").attribute(yyDollar[1].value, "true")
		}
	case 225:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:737
		{
			yyVAL.node = yyDollar[1].node.attribute(yyDollar[2].value, "true")
		}
	case 226:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:741
		{
			yyVAL.value = "abstract"
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:742
		{
			yyVAL.value = "final"
		}
	case 228:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:746
		{
			yyVAL.node = Node("Trait").attribute("name", yyDollar[2].token).append(yyDollar[4].node)
		}
	case 229:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:751
		{
			yyVAL.node = Node("Interface").
				attribute("name", yyDollar[2].token).
				append(Node("Extends").append(yyDollar[3].node)).
				append(yyDollar[5].node)
		}
	case 230:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:760
		{
			yyVAL.node = Node("")
		}
	case 231:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:761
		{
			yyVAL.node = yyDollar[2].node
		}
	case 232:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:765
		{
			yyVAL.node = Node("")
		}
	case 233:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:766
		{
			yyVAL.node = yyDollar[2].node
		}
	case 234:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:770
		{
			yyVAL.node = Node("")
		}
	case 235:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:771
		{
			yyVAL.node = yyDollar[2].node
		}
	case 236:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:775
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 237:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:776
		{
			yyVAL.node = Node("Stmt")
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:780
		{
			yyVAL.node = yyDollar[2].node.append(yyDollar[1].node)
		}
	case 239:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:781
		{
			yyVAL.node = yyDollar[3].node.append(yyDollar[1].node)
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:782
		{
			yyVAL.node = Node("Use").append(yyDollar[2].node).append(yyDollar[3].node)
		}
	case 241:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser.y:785
		{
			yyVAL.node = Node("Function").
				append(yyDollar[1].node).
				append(Node("name").append(yyDollar[4].node)).
				attribute("returns_ref", yyDollar[3].value).
				append(yyDollar[6].node).
				append(yyDollar[8].node).
				append(yyDollar[9].node)
		}
	case 242:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:797
		{
			yyVAL.node = Node("NameList").append(yyDollar[1].node)
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:798
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 244:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:802
		{
			yyVAL.node = Node("")
		}
	case 245:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:803
		{
			yyVAL.node = Node("")
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:804
		{
			yyVAL.node = yyDollar[2].node
		}
	case 247:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:808
		{
			yyVAL.node = Node("TraitAdaptionList").append(yyDollar[1].node)
		}
	case 248:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:809
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 249:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:813
		{
			yyVAL.node = yyDollar[1].node
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:814
		{
			yyVAL.node = yyDollar[1].node
		}
	case 251:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:819
		{
			yyVAL.node = Node("TraitPrecedence").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 252:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:823
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").attribute("value", yyDollar[3].token))
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:825
		{
			yyVAL.node = yyDollar[1].node.append(Node("as").append(Node("reservedNonModifiers")))
		}
	case 254:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:827
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:828
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 256:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:831
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node)
		}
	case 257:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:832
		{
			yyVAL.node = yyDollar[1].node
		}
	case 258:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:836
		{
			yyVAL.node = Node("TraitMethodRef").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 259:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:840
		{
			yyVAL.node = Node("")
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:841
		{
			yyVAL.node = yyDollar[2].node
		}
	case 261:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:845
		{
			yyVAL.node = yyDollar[1].node
		}
	case 262:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:846
		{
			yyVAL.node = Node("VarMemberModifier")
		}
	case 263:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:850
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 264:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:851
		{
			yyVAL.node = Node("ConstList").append(yyDollar[1].node)
		}
	case 265:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:855
		{
			yyVAL.node = Node("Const").append(yyDollar[3].node)
		}
	case 266:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:859
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 267:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:860
		{
			yyVAL.node = yyDollar[1].node
		}
	case 268:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:863
		{
			yyVAL.node = yyDollar[1].node
		}
	case 269:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:864
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 270:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:867
		{
			yyVAL.node = Node("PublicMemberModifier")
		}
	case 271:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:868
		{
			yyVAL.node = Node("ProtectedMemberModifier")
		}
	case 272:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:869
		{
			yyVAL.node = Node("PrivateMemberModifier")
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:870
		{
			yyVAL.node = Node("StaticMemberModifier")
		}
	case 274:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:871
		{
			yyVAL.node = Node("AbstractMemberModifier")
		}
	case 275:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:872
		{
			yyVAL.node = Node("FinalMemberModifier")
		}
	case 276:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:876
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 277:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:877
		{
			yyVAL.node = Node("PropertyList").append(yyDollar[1].node)
		}
	case 278:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:880
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token)
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:881
		{
			yyVAL.node = Node("Property").attribute("name", yyDollar[1].token).append(Node("Default").append(yyDollar[3].node))
		}
	case 280:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser.y:886
		{
			yyVAL.node = Node("Function").
				attribute("name", yyDollar[3].token).
				attribute("returns_ref", yyDollar[2].value).
				append(yyDollar[5].node).
				append(yyDollar[7].node).
				append(yyDollar[9].node)
		}
	case 281:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:897
		{
			yyVAL.node = yyDollar[1].node
		}
	case 282:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:898
		{
			yyVAL.node = Node("Parameter list")
		}
	case 283:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:901
		{
			yyVAL.node = Node("Parameter list").append(yyDollar[1].node)
		}
	case 284:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:902
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 285:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:906
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token)
		}
	case 286:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:914
		{
			yyVAL.node = Node("Parameter").
				append(yyDollar[1].node).
				attribute("is_reference", yyDollar[2].value).
				attribute("is_variadic", yyDollar[3].value).
				attribute("var", yyDollar[4].token).
				append(yyDollar[6].node)
		}
	case 287:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:925
		{
			yyVAL.node = Node("No type")
		}
	case 288:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:926
		{
			yyVAL.node = yyDollar[1].node
		}
	case 289:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:930
		{
			yyVAL.value = "false"
		}
	case 290:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:931
		{
			yyVAL.value = "true"
		}
	case 291:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:935
		{
			yyVAL.value = "false"
		}
	case 292:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:936
		{
			yyVAL.value = "true"
		}
	case 293:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:940
		{
			yyVAL.value = "false"
		}
	case 294:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:941
		{
			yyVAL.value = "true"
		}
	case 295:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:945
		{
			yyVAL.node = yyDollar[1].node
		}
	case 296:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:946
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.attribute("nullable", "true")
		}
	case 297:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:950
		{
			yyVAL.node = yyDollar[1].node
		}
	case 298:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:951
		{
			yyVAL.node = Node("array type")
		}
	case 299:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:952
		{
			yyVAL.node = Node("callable type")
		}
	case 300:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:956
		{
			yyVAL.node = Node("No return type")
		}
	case 301:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:957
		{
			yyVAL.node = yyDollar[2].node
		}
	case 302:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:961
		{
			yyVAL.node = Node("Assign").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 303:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:962
		{
			yyVAL.node = Node("AssignRef").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 304:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:963
		{
			yyVAL.node = Node("Clone").append(yyDollar[2].node)
		}
	case 305:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:964
		{
			yyVAL.node = Node("AssignAdd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 306:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:965
		{
			yyVAL.node = Node("AssignSub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 307:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:966
		{
			yyVAL.node = Node("AssignMul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 308:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:967
		{
			yyVAL.node = Node("AssignPow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 309:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:968
		{
			yyVAL.node = Node("AssignDiv").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 310:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:969
		{
			yyVAL.node = Node("AssignConcat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 311:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:970
		{
			yyVAL.node = Node("AssignMod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 312:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:971
		{
			yyVAL.node = Node("AssignAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 313:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:972
		{
			yyVAL.node = Node("AssignOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 314:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:973
		{
			yyVAL.node = Node("AssignXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:974
		{
			yyVAL.node = Node("AssignShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 316:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:975
		{
			yyVAL.node = Node("AssignShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 317:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:976
		{
			yyVAL.node = Node("PostIncrement").append(yyDollar[1].node)
		}
	case 318:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:977
		{
			yyVAL.node = Node("PreIncrement").append(yyDollar[2].node)
		}
	case 319:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:978
		{
			yyVAL.node = Node("PostDecrement").append(yyDollar[1].node)
		}
	case 320:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:979
		{
			yyVAL.node = Node("PreDecrement").append(yyDollar[2].node)
		}
	case 321:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:980
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 322:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:981
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 323:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:982
		{
			yyVAL.node = Node("Or").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 324:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:983
		{
			yyVAL.node = Node("And").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:984
		{
			yyVAL.node = Node("Xor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:985
		{
			yyVAL.node = Node("BitwiseOr").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 327:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:986
		{
			yyVAL.node = Node("BitwiseAnd").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 328:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:987
		{
			yyVAL.node = Node("BitwiseXor").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 329:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:988
		{
			yyVAL.node = Node("Concat").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 330:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:989
		{
			yyVAL.node = Node("Add").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 331:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:990
		{
			yyVAL.node = Node("Sub").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 332:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:991
		{
			yyVAL.node = Node("Mul").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 333:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:992
		{
			yyVAL.node = Node("Pow").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 334:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:993
		{
			yyVAL.node = Node("Div").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 335:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:994
		{
			yyVAL.node = Node("Mod").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 336:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:995
		{
			yyVAL.node = Node("ShiftLeft").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 337:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:996
		{
			yyVAL.node = Node("ShiftRight").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 338:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:997
		{
			yyVAL.node = Node("UnaryPlus").append(yyDollar[2].node)
		}
	case 339:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:998
		{
			yyVAL.node = Node("UnaryMinus").append(yyDollar[2].node)
		}
	case 340:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:999
		{
			yyVAL.node = Node("BooleanNot").append(yyDollar[2].node)
		}
	case 341:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1000
		{
			yyVAL.node = Node("BitwiseNot").append(yyDollar[2].node)
		}
	case 342:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1001
		{
			yyVAL.node = Node("Identical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 343:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1002
		{
			yyVAL.node = Node("NotIdentical").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 344:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1003
		{
			yyVAL.node = Node("Equal").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 345:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1004
		{
			yyVAL.node = Node("NotEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 346:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1005
		{
			yyVAL.node = Node("Spaceship").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 347:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1006
		{
			yyVAL.node = Node("Smaller").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 348:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1007
		{
			yyVAL.node = Node("SmallerOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 349:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1008
		{
			yyVAL.node = Node("Greater").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 350:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1009
		{
			yyVAL.node = Node("GreaterOrEqual").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 351:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1010
		{
			yyVAL.node = Node("InstanceOf").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 352:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1011
		{
			yyVAL.node = yyDollar[2].node
		}
	case 353:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1012
		{
			yyVAL.node = yyDollar[1].node
		}
	case 354:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:1013
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[5].node)
		}
	case 355:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1014
		{
			yyVAL.node = Node("Ternary").append(yyDollar[1].node).append(yyDollar[4].node)
		}
	case 356:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1015
		{
			yyVAL.node = Node("Coalesce").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 357:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1016
		{
			yyVAL.node = yyDollar[1].node
		}
	case 358:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1017
		{
			yyVAL.node = Node("CastInt").append(yyDollar[2].node)
		}
	case 359:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1018
		{
			yyVAL.node = Node("CastDouble").append(yyDollar[2].node)
		}
	case 360:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1019
		{
			yyVAL.node = Node("CastString").append(yyDollar[2].node)
		}
	case 361:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1020
		{
			yyVAL.node = Node("CastArray").append(yyDollar[2].node)
		}
	case 362:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1021
		{
			yyVAL.node = Node("CastObject").append(yyDollar[2].node)
		}
	case 363:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1022
		{
			yyVAL.node = Node("CastBool").append(yyDollar[2].node)
		}
	case 364:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1023
		{
			yyVAL.node = Node("CastUnset").append(yyDollar[2].node)
		}
	case 365:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1024
		{
			yyVAL.node = Node("Silence").append(yyDollar[2].node)
		}
	case 366:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1025
		{
			yyVAL.node = yyDollar[1].node
		}
	case 367:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1026
		{
			yyVAL.node = Node("Print").append(yyDollar[2].node)
		}
	case 368:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1027
		{
			yyVAL.node = Node("Yield")
		}
	case 369:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1028
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node)
		}
	case 370:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1029
		{
			yyVAL.node = Node("Yield").append(yyDollar[2].node).append(yyDollar[4].node)
		}
	case 371:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1030
		{
			yyVAL.node = Node("YieldFrom").append(yyDollar[2].node)
		}
	case 372:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1034
		{
			yyVAL.node = Node("Scalar").append(Node("Lnumber").attribute("value", yyDollar[1].token))
		}
	case 373:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1035
		{
			yyVAL.node = Node("Scalar").append(Node("Dnumber").attribute("value", yyDollar[1].token))
		}
	case 374:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1036
		{
			yyVAL.node = Node("Scalar").append(Node("__LINE__"))
		}
	case 375:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1037
		{
			yyVAL.node = Node("Scalar").append(Node("__FILE__"))
		}
	case 376:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1038
		{
			yyVAL.node = Node("Scalar").append(Node("__DIR__"))
		}
	case 377:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1039
		{
			yyVAL.node = Node("Scalar").append(Node("__TRAIT__"))
		}
	case 378:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1040
		{
			yyVAL.node = Node("Scalar").append(Node("__METHOD__"))
		}
	case 379:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1041
		{
			yyVAL.node = Node("Scalar").append(Node("__FUNCTION__"))
		}
	case 380:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1042
		{
			yyVAL.node = Node("Scalar").append(Node("__NAMESPACE__"))
		}
	case 381:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1043
		{
			yyVAL.node = Node("Scalar").append(Node("__CLASS__"))
		}
	case 382:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1045
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc").attribute("value", yyDollar[2].token))
		}
	case 383:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1047
		{
			yyVAL.node = Node("Scalar").append(Node("Heredoc"))
		}
	case 384:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1048
		{
			yyVAL.node = yyDollar[2].node
		}
	case 385:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1049
		{
			yyVAL.node = yyDollar[2].node
		}
	case 386:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1050
		{
			yyVAL.node = yyDollar[1].node
		}
	case 387:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1051
		{
			yyVAL.node = yyDollar[1].node
		}
	case 388:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1055
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[2].node)
		}
	case 389:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1056
		{
			yyVAL.node = yyDollar[1].node.append(Node("String").attribute("value", yyDollar[2].token))
		}
	case 390:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1057
		{
			yyVAL.node = Node("EncapsList").append(yyDollar[1].node)
		}
	case 391:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1058
		{
			yyVAL.node = Node("EncapsList").append(Node("String").attribute("value", yyDollar[1].token)).append(yyDollar[2].node)
		}
	case 392:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1061
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token)
		}
	case 393:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1062
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("offset").append(yyDollar[3].node))
		}
	case 394:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1063
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[1].token).append(Node("property").attribute("value", yyDollar[3].token))
		}
	case 395:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1064
		{
			yyVAL.node = Node("Variable").append(Node("expr").append(yyDollar[2].node))
		}
	case 396:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1065
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token)
		}
	case 397:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser.y:1067
		{
			yyVAL.node = Node("Variable").attribute("value", yyDollar[2].token).append(Node("offset").append(yyDollar[4].node))
		}
	case 398:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1068
		{
			yyVAL.node = yyDollar[2].node
		}
	case 399:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1071
		{
			yyVAL.node = Node("OffsetString").attribute("value", yyDollar[1].token)
		}
	case 400:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1072
		{
			yyVAL.node = Node("OffsetNumString").attribute("value", yyDollar[1].token)
		}
	case 401:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1073
		{
			yyVAL.node = Node("OffsetNegateNumString").attribute("value", yyDollar[2].token)
		}
	case 402:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1074
		{
			yyVAL.node = Node("OffsetVariable").attribute("value", yyDollar[1].token)
		}
	case 403:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser.y:1078
		{
			yyVAL.node = yyDollar[3].node
		}
	case 404:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1079
		{
			yyVAL.node = Node("Empty").append(yyDollar[3].node)
		}
	case 405:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1080
		{
			yyVAL.node = Node("Include").append(yyDollar[2].node)
		}
	case 406:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1081
		{
			yyVAL.node = Node("IncludeOnce").append(yyDollar[2].node)
		}
	case 407:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1082
		{
			yyVAL.node = Node("Eval").append(yyDollar[3].node)
		}
	case 408:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1083
		{
			yyVAL.node = Node("Require").append(yyDollar[2].node)
		}
	case 409:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1084
		{
			yyVAL.node = Node("RequireOnce").append(yyDollar[2].node)
		}
	case 410:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1088
		{
			yyVAL.node = yyDollar[1].node
		}
	case 411:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1089
		{
			yyVAL.node = Node("AndIsset").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 412:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1093
		{
			yyVAL.node = Node("Isset").append(yyDollar[1].node)
		}
	case 413:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1097
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node)
		}
	case 414:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1098
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 415:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1100
		{
			yyVAL.node = Node("Const").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 416:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1104
		{
			yyVAL.node = Node("Static")
		}
	case 417:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1105
		{
			yyVAL.node = yyDollar[1].node
		}
	case 418:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1109
		{
			yyVAL.node = yyDollar[1].node
		}
	case 419:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1110
		{
			yyVAL.node = yyDollar[1].node
		}
	case 420:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1114
		{
			yyVAL.node = yyDollar[1].node
		}
	case 421:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1118
		{
			yyVAL.node = yyDollar[1].node
		}
	case 422:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1119
		{
			yyVAL.node = yyDollar[2].node
		}
	case 423:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1120
		{
			yyVAL.node = yyDollar[1].node
		}
	case 424:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1124
		{
			yyVAL.node = yyDollar[1].node
		}
	case 425:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1125
		{
			yyVAL.node = yyDollar[2].node
		}
	case 426:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1126
		{
			yyVAL.node = yyDollar[1].node
		}
	case 427:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1130
		{
			yyVAL.node = yyDollar[3].node
		}
	case 428:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1131
		{
			yyVAL.node = yyDollar[2].node
		}
	case 429:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1132
		{
			yyVAL.node = Node("String").attribute("value", yyDollar[1].token)
		}
	case 430:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1136
		{
			yyVAL.node = yyDollar[1].node
		}
	case 431:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1137
		{
			yyVAL.node = yyDollar[1].node
		}
	case 432:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser.y:1141
		{
			yyVAL.node = Node("")
		}
	case 433:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1142
		{
			yyVAL.node = yyDollar[1].node
		}
	case 434:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1146
		{
			yyVAL.node = yyDollar[1].node
		}
	case 435:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1147
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 436:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1148
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 437:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1149
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 438:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1151
		{
			yyVAL.node = Node("MethodCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 439:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1152
		{
			yyVAL.node = yyDollar[1].node
		}
	case 440:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1156
		{
			yyVAL.node = Node("FunctionCall").append(yyDollar[1].node).append(yyDollar[2].node)
		}
	case 441:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1158
		{
			yyVAL.node = Node("StaticCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 442:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1160
		{
			yyVAL.node = Node("StaticCall").append(yyDollar[1].node).append(yyDollar[3].node).append(yyDollar[4].node)
		}
	case 443:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1161
		{
			yyVAL.node = Node("Call").append(yyDollar[1].node).append(yyDollar[2].node)
		}
	case 444:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1165
		{
			yyVAL.node = yyDollar[1].node
		}
	case 445:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1166
		{
			yyVAL.node = yyDollar[2].node
		}
	case 446:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1167
		{
			yyVAL.node = yyDollar[1].node
		}
	case 447:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1171
		{
			yyVAL.node = Node("ArgumentList")
		}
	case 448:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1172
		{
			yyVAL.node = yyDollar[2].node
		}
	case 449:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1175
		{
			yyVAL.node = Node("ArgumentList").append(yyDollar[1].node)
		}
	case 450:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1176
		{
			yyVAL.node = yyDollar[1].node.append(yyDollar[3].node)
		}
	case 451:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1179
		{
			yyVAL.node = yyDollar[1].node
		}
	case 452:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1180
		{
			yyVAL.node = Node("Unpack").append(yyDollar[2].node)
		}
	case 453:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1184
		{
			yyVAL.node = yyDollar[1].node
		}
	case 454:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1185
		{
			yyVAL.node = yyDollar[1].node
		}
	case 455:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1186
		{
			yyVAL.node = Node("Property").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 456:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1190
		{
			yyVAL.node = Node("PropertyName").attribute("value", yyDollar[1].token)
		}
	case 457:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1191
		{
			yyVAL.node = yyDollar[2].node
		}
	case 458:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1192
		{
			yyVAL.node = yyDollar[1].node
		}
	case 459:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1196
		{
			yyVAL.node = Node("Variable").attribute("name", yyDollar[1].token)
		}
	case 460:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1197
		{
			yyVAL.node = Node("Variable").append(yyDollar[3].node)
		}
	case 461:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser.y:1198
		{
			yyVAL.node = Node("Variable").append(yyDollar[2].node)
		}
	case 462:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1203
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 463:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1205
		{
			yyVAL.node = Node("StaticProp").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 464:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser.y:1208
		{
			yyVAL.node = yyDollar[1].node
		}
	case 465:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1209
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 466:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser.y:1210
		{
			yyVAL.node = Node("Dim").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 467:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1211
		{
			yyVAL.node = Node("Property").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 468:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1213
		{
			yyVAL.node = Node("StaticProperty").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	case 469:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser.y:1215
		{
			yyVAL.node = Node("StaticProperty").append(yyDollar[1].node).append(yyDollar[3].node)
		}
	}
	goto yystack /* stack new state and value */
}
